# -*- coding: utf-8 -*-
r""" Master Server Query Protocol

This module implements the legacy Steam master server protocol.

https://developer.valvesoftware.com/wiki/Master_Server_Query_Protocol

Nowadays games query servers through Steam. See :any:`steam.client.builtins.gameservers`

Filters
-------

.. note::
    Multiple filters can be joined to together (Eg. ``\appid\730\white\1\empty\1``)

=========================== =========================================================================================================================
Filter code                 What it does
=========================== =========================================================================================================================
\\nor\\[x]                  A special filter, specifies that servers matching any of the following [x] conditions should not be returned
\\nand\\[x]                 A special filter, specifies that servers matching all of the following [x] conditions should not be returned
\\dedicated\\1              Servers running dedicated
\\secure\\1                 Servers using anti-cheat technology (VAC, but potentially others as well)
\\gamedir\\[mod]            Servers running the specified modification (ex. cstrike)
\\map\\[map]                Servers running the specified map (ex. cs_italy)
\\linux\\1                  Servers running on a Linux platform
\\password\\0               Servers that are not password protected
\\empty\\1                  Servers that are not empty
\\full\\1                   Servers that are not full
\\proxy\\1                  Servers that are spectator proxies
\\appid\\[appid]            Servers that are running game [appid]
\\napp\\[appid]             Servers that are NOT running game [appid] (This was introduced to block Left 4 Dead games from the Steam Server Browser)
\\noplayers\\1              Servers that are empty
\\white\\1                  Servers that are whitelisted
\\gametype\\[tag,...]       Servers with all of the given tag(s) in sv_tags
\\gamedata\\[tag,...]       Servers with all of the given tag(s) in their 'hidden' tags (L4D2)
\\gamedataor\\[tag,...]     Servers with any of the given tag(s) in their 'hidden' tags (L4D2)
\\name_match\\[hostname]    Servers with their hostname matching [hostname] (can use * as a wildcard)
\\version_match\\[version]  Servers running version [version] (can use * as a wildcard)
\\collapse_addr_hash\\1     Return only one server for each unique IP address matched
\\gameaddr\\[ip]            Return only servers on the specified IP address (port supported and optional)
=========================== =========================================================================================================================

Examples
--------

Query HL Master

.. code:: python

    >>> for server_addr in gs.query_master(r'\appid\730\white\1', max_servers=3):
    ...     print(server_addr)
    ...
    ('146.66.152.197', 27073)
    ('146.66.153.124', 27057)
    ('146.66.152.56', 27053)

Team Fortress 2 (Source)

.. code:: python

    >>> from steam import game_servers as gs
    >>> server_addr = next(gs.query_master(r'\appid\40\empty\1\secure\1'))  # single TF2 Server
    >>> gs.a2s_ping(server_addr)
    68.60899925231934
    >>> gs.a2s_info(server_addr)
    {'_ping': 74.61714744567871,
     '_type': 'source',
     'app_id': 40,
     'bots': 0,
     'environment': 'l',
     'folder': u'dmc',
     'game': u'DMC\t\t\t\t\t\t\t\t1',
     'map': u'crossfire',
     'max_players': 32,
     'name': u'\t\t\u2605\t\t All Guns party \u2605\t \tCrossfire 24/7\t\t',
     'players': 21,
     'protocol': 48,
     'server_type': 'd',
     'vac': 1,
     'visibility': 0}
    >>> gs.a2s_players(server_addr)
    [{'duration': 192.3097381591797, 'index': 0, 'name': '(2)Player', 'score': 4},
     {'duration': 131.6618194580078, 'index': 1, 'name': 'BOLT', 'score': 2},
     {'duration': 16.548809051513672, 'index': 2, 'name': 'Alpha', 'score': 0},
     {'duration': 1083.1539306640625, 'index': 3, 'name': 'Player', 'score': 29},
     {'duration': 446.7716064453125, 'index': 4, 'name': '(1)Player', 'score': 11},
     {'duration': 790.9588012695312, 'index': 5, 'name': 'ИВАНГАЙ', 'score': 11}]
    >>> gs.a2s_rules(server_addr)
    {'amx_client_languages': 1,
     'amx_nextmap': 'crossfire',
     'amx_timeleft': '00:00',
     'amxmodx_version': '1.8.2',
     ....

Ricohet (GoldSrc)

.. code:: python

    >>> from steam import game_servers as gs
    >>> server_addr = next(gs.query_master(r'\appid\60'))  # get a single ip from hl2 master
    >>> gs.a2s_info(server_addr, force_goldsrc=True)       # only accept goldsrc response
    {'_ping': 26.59320831298828,
     '_type': 'goldsrc',
     'address': '127.0.0.1:27050',
     'bots': 0,
     'ddl': 0,
     'download_link': '',
     'environment': 'w',
     'folder': 'ricochet',
     'game': 'Ricochet',
     'link': '',
     'map': 'rc_deathmatch2',
     'max_players': 32,
     'mod': 1,
     'name': 'Anitalink.com Ricochet',
     'players': 1,
     'protocol': 47,
     'server_type': 'd',
     'size': 0,
     'type': 1,
     'vac': 1,
     'version': 1,
     'visibility': 0}

API
---
"""
import socket
from binascii import crc32
from bz2 import decompress as _bz2_decompress
from re import match as _re_match
from struct import pack as _pack, unpack_from as _unpack_from
from time import time as _time
from enum import IntEnum
from steam.utils.binary import StructReader as _StructReader

__all__ = ['query_master', 'a2s_info', 'a2s_players', 'a2s_rules', 'a2s_ping']


def _u(data):
    return data.decode('utf-8', 'replace')


class StructReader(_StructReader):
    def read_cstring(self, binary=False):
        raw = super(StructReader, self).read_cstring()
        if binary:
            return raw
        return _u(raw)


class MSRegion(IntEnum):
    US_East = 0x00
    US_West = 0x01
    South_America = 0x02
    Europe = 0x03
    Asia = 0x04
    Australia = 0x05
    Middle_East = 0x06
    Africa = 0x07
    World = 0xFF


class MSServer:
    GoldSrc = ('hl1master.steampowered.com', 27010)  #: These have been shutdown
    Source = ('hl2master.steampowered.com', 27011)
    Source_27015 = ('208.64.200.65', 27015)          #: ``hl2master`` but on different port


def query_master(filter_text=r'\nappid\500', max_servers=20, region=MSRegion.World, master=MSServer.Source, timeout=2):
    r"""Generator that returns (IP,port) pairs of servers

    .. warning::
        Valve's master servers seem to be heavily rate limited.
        Queries that return a large numbers IPs will timeout before returning everything.
        There is no way to resume the query.
        Use :class:`SteamClient` to access game servers in a reliable way.

    .. note::
        When specifying ``filter_text`` use *raw strings* otherwise python won't treat backslashes
        as literal characters (e.g. ``query(r'\appid\730\white\1')``)

    :param filter_text: filter for servers
    :type  filter_text: str
    :param region: (optional) region code
    :type  region: :class:`.MSRegion`
    :param master: (optional) master server to query
    :type  master: (:class:`str`, :class:`int`)
    :raises: :class:`RuntimeError`, :class:`socket.timeout`
    :returns: a generator yielding (ip, port) pairs
    :rtype: :class:`generator`
    """

    if not isinstance(region, MSRegion):
        raise TypeError("region_code is not of type MSRegion")

    ms = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    ms.connect(master)
    ms.settimeout(timeout)

    next_ip = b'0.0.0.0:0'
    req_prefix = b'1' + _pack('>B', region)
    req_suffix = b'\x00' + filter_text.encode('utf-8') + b'\x00'
    n = 0

    while True:
        ms.send(req_prefix + next_ip + req_suffix)

        data = StructReader(ms.recv(8196))  # chunk size needs to be multiple of 6

        # verify response header
        if data.read(6) != b'\xFF\xFF\xFF\xFF\x66\x0A':
            ms.close()
            raise RuntimeError("Invalid response from master server")

        # read list of servers
        while data.rlen():
            ip = '.'.join(map(str, data.unpack('>BBBB')))
            port, = data.unpack('>H')
            n += 1

            # check if we've reached the end of the list
            if ip == '0.0.0.0' and port == 0:
                ms.close()
                return

            yield ip, port

            if n >= max_servers:
                ms.close()
                return

        next_ip = '{}:{}'.format(ip, port).encode('utf-8')

    ms.close()


def _handle_a2s_response(sock):
    packet = sock.recv(2048)
    header, = _unpack_from('<l', packet)

    if header == -1:  # single packet response
        return packet
    elif header == -2:  # multi packet response
        sock.settimeout(0.3)
        return _handle_a2s_multi_packet_response(sock, packet)
    else:
        raise RuntimeError("Invalid response header - %d" % header)


def _handle_a2s_multi_packet_response(sock, packet):
    packets, payload_offset = [packet], -1

    # locate first packet and handle out of order packets
    while payload_offset == -1:
        # locate payload offset in uncompressed packet
        payload_offset = packet.find(b'\xff\xff\xff\xff', 0, 18)

        # locate payload offset in compressed packet
        if payload_offset == -1:
            payload_offset = packet.find(b'BZh', 0, 21)

        # if we still haven't found the offset receive the next packet
        if payload_offset == -1:
            packet = sock.recv(2048)
            packets.append(packet)

    # read header
    pkt_idx, num_pkts, compressed = _unpack_multipacket_header(payload_offset, packet)

    if pkt_idx != 0:
        raise RuntimeError("Unexpected first packet index")

    # recv any remaining packets
    while len(packets) < num_pkts:
        packets.append(sock.recv(2048))

    # ensure packets are in correct order
    packets = sorted(map(lambda pkt: (_unpack_multipacket_header(payload_offset, pkt)[0], pkt),
                         packets,
                         ),
                     key=lambda x: x[0])

    # reconstruct full response
    data = b''.join(map(lambda x: x[1][payload_offset:], packets))

    # decompress response if needed
    if compressed:
        size, checksum = _unpack_from('<ll', packet, 10)
        data = _bz2_decompress(data)

        if len(data) != size:
            raise RuntimeError("Response size mismatch - %d %d" % (len(data), size))
        if checksum != crc32(data):
            raise RuntimeError("Response checksum mismatch - %d %d" % (checksum, crc32(data)))

    return data


def _unpack_multipacket_header(payload_offset, packet):
    if payload_offset == 9:  # GoldSrc
        pkt_byte, = _unpack_from('<B', packet, 8)
        return pkt_byte >> 2, pkt_byte & 0xF, False  # idx, total, compressed
    elif payload_offset in (10, 12, 18):  # Source
        pkt_id, num_pkts, pkt_idx, = _unpack_from('<LBB', packet, 4)
        return pkt_idx, num_pkts, (pkt_id & 0x80000000) != 0   # idx, total, compressed
    else:
        raise RuntimeError("Unexpected payload_offset - %d" % payload_offset)


def a2s_info(server_addr, timeout=2, force_goldsrc=False, challenge=0):
    """Get information from a server

    .. note::
        All ``GoldSrc`` games have been updated to reply in ``Source`` format.
        ``GoldSrc`` format is essentially DEPRECATED.
        By default the function will prefer to return ``Source`` format, and will
        automatically fallback to ``GoldSrc`` if available.

    :param server_addr: (ip, port) for the server
    :type  server_addr: tuple
    :param force_goldsrc: (optional) only accept ``GoldSrc`` response format
    :type  force_goldsrc: :class:`bool`
    :param timeout: (optional) timeout in seconds
    :type  timeout: float
    :param challenge: (optional) optionally supply a challenge in accordance to a2s protocol changes from December 2020
    :type challenge: int
    :raises: :class:`RuntimeError`, :class:`socket.timeout`
    :returns: a dict with information or `None` on timeout
    :rtype: :class:`dict`
    """
    ss = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    ss.connect(server_addr)
    ss.settimeout(timeout)

    # request server info
    payload = _pack('<lc', -1, b'T') + b'Source Engine Query\x00'
    if challenge not in (-1, 0): # If a valid challenge was supplied, append it to the payload
        payload += _pack('<i', challenge)

    ss.send(payload)
    start = _time()

    # handle response(s)
    try:
        data = _handle_a2s_response(ss)
    except:
        ss.close()
        raise

    ping = max(0.0, _time() - start) * 1000

    if force_goldsrc:
        if data[4:5] != b'm':
            ss.close()
            raise socket.timeout('time out')
    else:
        # we got a valid GoldSrc response, check if it is followed by Source response
        if data[4:5] == b'm':
            ss.settimeout(0.3)
            try:
                data = _handle_a2s_response(ss)
            except socket.timeout:
                pass

    ss.close()
    data = StructReader(data)
    header, = data.unpack('<4xc')

    # invalid header
    if header not in b'mIA':
        raise RuntimeError("Invalid response header - %s" % repr(header))
    # GoldSrc response
    elif header == b'm':
        info = {
            '_ping': ping,
            '_type': 'goldsrc',
            'address': data.read_cstring(),
            'name': data.read_cstring(),
            'map': data.read_cstring(),
            'folder': data.read_cstring(),
            'game': data.read_cstring(),
        }

        (info['players'],
         info['max_players'],
         info['protocol'],
         info['server_type'],
         info['environment'],
         info['visibility'],
         info['mod'],
         ) = data.unpack('<BBBccBB')

        info['server_type'] = _u(info['server_type'])
        info['environment'] = _u(info['environment'])

        if info['mod'] == 1:
            info['link'] = data.read_cstring()
            info['download_link'] = data.read_cstring()

            (info['version'],
             info['size'],
             info['type'],
             info['ddl'],
             ) = data.unpack('<xLLBB')

        info['vac'], info['bots'] = data.unpack('<BB')
    # Source response
    elif header == b'I':
        info = {
            '_ping': ping,
            '_type': 'source',
            'protocol': data.unpack('<b')[0],
            'name': data.read_cstring(),
            'map': data.read_cstring(),
            'folder': data.read_cstring(),
            'game': data.read_cstring(),
        }

        (info['app_id'],
         info['players'],
         info['max_players'],
         info['bots'],
         info['server_type'],
         info['environment'],
         info['visibility'],
         info['vac'],
         ) = data.unpack('<HBBBccBB')

        info['server_type'] = _u(info['server_type'])
        info['environment'] = _u(info['environment'])

        if info['app_id'] == 2400:
            (info['mode'],
             info['witnesses'],
             info['duration'],
             ) = data.unpack('<BBB')

        info['version'] = data.read_cstring()

        if data.rlen():
            edf, = data.unpack('<B')
            info['edf'] = edf

            if edf & 0x80:
                info['port'], = data.unpack('<H')
            if edf & 0x10:
                info['steam_id'], = data.unpack('<Q')
            if edf & 0x40:
                info['sourcetv_port'], = data.unpack('<H')
                info['sourcetv_name'] = data.read_cstring()
            if edf & 0x20:
                info['keywords'] = data.read_cstring()
            if edf & 0x01:
                info['game_id'], = data.unpack('<Q')
                info['app_id'] = info['game_id'] & 0xFFFFFF
    # Challenge response
    elif header == b'A':
        if challenge not in (-1, 0):
            raise RuntimeError("Invalid response header for request containing challenge answer - %s" % repr(header))

        challenge = data.unpack('<l')
        return a2s_info(server_addr = server_addr, timeout = timeout, force_goldsrc = force_goldsrc, challenge = challenge[0])

    return info


def a2s_players(server_addr, timeout=2, challenge=0):
    """Get list of players and their info

    :param server_addr: (ip, port) for the server
    :type  server_addr: tuple
    :param timeout: (optional) timeout in seconds
    :type  timeout: float
    :param challenge: (optional) challenge number
    :type  challenge: int
    :raises: :class:`RuntimeError`, :class:`socket.timeout`
    :returns: a list of players
    :rtype: :class:`list`
    """
    ss = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    ss.connect(server_addr)
    ss.settimeout(timeout)

    # request challenge number
    header = None

    if challenge in (-1, 0):
        ss.send(_pack('<lci', -1, b'U', challenge))
        try:
            data = ss.recv(512)
            _, header, challenge = _unpack_from('<lcl', data)
        except:
            ss.close()
            raise

        if header not in b'AD':  # work around for CSGO sending only max players
            raise RuntimeError("Unexpected challenge response - %s" % repr(header))

    # request player info
    if header == b'D':  # work around for CSGO sending only max players
        data = StructReader(data)
    else:
        ss.send(_pack('<lci', -1, b'U', challenge))

        try:
            data = StructReader(_handle_a2s_response(ss))
        finally:
            ss.close()

    header, num_players = data.unpack('<4xcB')

    if header != b'D':
        raise RuntimeError("Invalid response header - %s" % repr(header))

    players = []

    while len(players) < num_players:
        player = dict()
        player['index'] = data.unpack('<B')[0]
        player['name'] = data.read_cstring()
        player['score'], player['duration'] = data.unpack('<lf')
        players.append(player)

    if data.rlen() / 8 == num_players:  # assume the ship server
        for player in players:
            player['deaths'], player['money'] = data.unpack('<ll')

    return players


def a2s_rules(server_addr, timeout=2, challenge=0, binary=False):
    """Get rules from server

    :param server_addr: (ip, port) for the server
    :type  server_addr: tuple
    :param timeout: (optional) timeout in seconds
    :type  timeout: float
    :param challenge: (optional) challenge number
    :type  challenge: int
    :param binary: (optional) return rules as raw bytes
    :type  binary: bool
    :raises: :class:`RuntimeError`, :class:`socket.timeout`
    :returns: a list of rules
    :rtype: :class:`dict`
    """
    ss = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    ss.connect(server_addr)
    ss.settimeout(timeout)

    # request challenge number
    if challenge in (-1, 0):
        ss.send(_pack('<lci', -1, b'V', challenge))
        try:
            _, header, challenge = _unpack_from('<lcl', ss.recv(512))
        except:
            ss.close()
            raise

        if header != b'A':
            raise RuntimeError("Unexpected challenge response")

    # request player info
    ss.send(_pack('<lci', -1, b'V', challenge))

    try:
        data = StructReader(_handle_a2s_response(ss))
    finally:
        ss.close()

    header, num_rules = data.unpack('<4xcH')

    if header != b'E':
        raise RuntimeError("Invalid response header - %s" % repr(header))

    rules = {}

    while len(rules) != num_rules:
        name = data.read_cstring(binary=binary)
        value = data.read_cstring(binary=binary)

        if not binary:
            if _re_match(r'^\-?[0-9]+$', value):
                value = int(value)
            elif _re_match(r'^\-?[0-9]+\.[0-9]+$', value):
                value = float(value)

        rules[name] = value

    return rules


def a2s_ping(server_addr, timeout=2):
    """Ping a server

    .. warning::
        This method for pinging is considered deprecated and may not work on certian servers.
        Use :func:`.a2s_info` instead.

    :param server_addr: (ip, port) for the server
    :type  server_addr: tuple
    :param timeout: (optional) timeout in seconds
    :type  timeout: float
    :raises: :class:`RuntimeError`, :class:`socket.timeout`
    :returns: ping response in milliseconds or `None` for timeout
    :rtype: :class:`float`
    """
    ss = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    ss.connect(server_addr)
    ss.settimeout(timeout)

    ss.send(_pack('<lc', -1, b'i'))
    start = _time()

    try:
        data = _handle_a2s_response(ss)
    finally:
        ss.close()

    ping = max(0.0, _time() - start) * 1000

    if data[4:5] == b'j':
        return ping



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_market.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asteammessages_market.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"=\n(CEconMarket_IsMarketplaceAllowed_Request\x12\x11\n\twebcookie\x18\x01 \x01(\t\"\xe6\x01\n)CEconMarket_IsMarketplaceAllowed_Response\x12\x0f\n\x07\x61llowed\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\r\x12\x17\n\x0f\x61llowed_at_time\x18\x03 \x01(\r\x12 \n\x18steamguard_required_days\x18\x04 \x01(\r\x12\x17\n\x0f\x66orms_requested\x18\x07 \x01(\x08\x12\"\n\x1a\x66orms_require_verification\x18\x08 \x01(\x08\x12 \n\x18new_device_cooldown_days\x18\t \x01(\r2{\n\nEconMarket\x12m\n\x14IsMarketplaceAllowed\x12).CEconMarket_IsMarketplaceAllowed_Request\x1a*.CEconMarket_IsMarketplaceAllowed_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_market_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CECONMARKET_ISMARKETPLACEALLOWED_REQUEST._serialized_start=90
  _CECONMARKET_ISMARKETPLACEALLOWED_REQUEST._serialized_end=151
  _CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE._serialized_start=154
  _CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE._serialized_end=384
  _ECONMARKET._serialized_start=386
  _ECONMARKET._serialized_end=509
_builder.BuildServices(DESCRIPTOR, 'steammessages_market_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_timedtrial.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esteammessages_timedtrial.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"5\n$CTimedTrial_GetTimeRemaining_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\x84\x01\n%CTimedTrial_GetTimeRemaining_Response\x12\x16\n\x0eseconds_played\x18\x01 \x01(\r\x12\x17\n\x0fseconds_allowed\x18\x02 \x01(\r\x12\x11\n\tpackageid\x18\x03 \x01(\r\x12\x17\n\x0fmastersub_appid\x18\x04 \x01(\r\"K\n\"CTimedTrial_RecordPlaytime_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x16\n\x0eseconds_played\x18\x02 \x01(\r\"V\n#CTimedTrial_RecordPlaytime_Response\x12\x16\n\x0eseconds_played\x18\x01 \x01(\r\x12\x17\n\x0fseconds_allowed\x18\x02 \x01(\r\"2\n!CTimedTrial_ResetPlaytime_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"U\n\"CTimedTrial_ResetPlaytime_Response\x12\x16\n\x0eseconds_played\x18\x01 \x01(\r\x12\x17\n\x0fseconds_allowed\x18\x02 \x01(\r2\xa6\x02\n\nTimedTrial\x12\x61\n\x10GetTimeRemaining\x12%.CTimedTrial_GetTimeRemaining_Request\x1a&.CTimedTrial_GetTimeRemaining_Response\x12[\n\x0eRecordPlaytime\x12#.CTimedTrial_RecordPlaytime_Request\x1a$.CTimedTrial_RecordPlaytime_Response\x12X\n\rResetPlaytime\x12\".CTimedTrial_ResetPlaytime_Request\x1a#.CTimedTrial_ResetPlaytime_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_timedtrial_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CTIMEDTRIAL_GETTIMEREMAINING_REQUEST._serialized_start=94
  _CTIMEDTRIAL_GETTIMEREMAINING_REQUEST._serialized_end=147
  _CTIMEDTRIAL_GETTIMEREMAINING_RESPONSE._serialized_start=150
  _CTIMEDTRIAL_GETTIMEREMAINING_RESPONSE._serialized_end=282
  _CTIMEDTRIAL_RECORDPLAYTIME_REQUEST._serialized_start=284
  _CTIMEDTRIAL_RECORDPLAYTIME_REQUEST._serialized_end=359
  _CTIMEDTRIAL_RECORDPLAYTIME_RESPONSE._serialized_start=361
  _CTIMEDTRIAL_RECORDPLAYTIME_RESPONSE._serialized_end=447
  _CTIMEDTRIAL_RESETPLAYTIME_REQUEST._serialized_start=449
  _CTIMEDTRIAL_RESETPLAYTIME_REQUEST._serialized_end=499
  _CTIMEDTRIAL_RESETPLAYTIME_RESPONSE._serialized_start=501
  _CTIMEDTRIAL_RESETPLAYTIME_RESPONSE._serialized_end=586
  _TIMEDTRIAL._serialized_start=589
  _TIMEDTRIAL._serialized_end=883
_builder.BuildServices(DESCRIPTOR, 'steammessages_timedtrial_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_datapublisher.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!steammessages_datapublisher.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x88\x02\n9CDataPublisher_ClientContentCorruptionReport_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65potid\x18\x02 \x01(\r\x12\x17\n\x0f\x64ownload_source\x18\x03 \x01(\t\x12\x10\n\x08objectid\x18\x04 \x01(\t\x12\x0e\n\x06\x63\x65llid\x18\x05 \x01(\r\x12\x13\n\x0bis_manifest\x18\x06 \x01(\x08\x12\x13\n\x0bobject_size\x18\x07 \x01(\x04\x12\x17\n\x0f\x63orruption_type\x18\x08 \x01(\r\x12\x12\n\nused_https\x18\t \x01(\x08\x12\x19\n\x11oc_proxy_detected\x18\n \x01(\x08\"\xf8\x04\n.CDataPublisher_ClientUpdateAppJob_Notification\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tdepot_ids\x18\x02 \x03(\r\x12\x11\n\tapp_state\x18\x03 \x01(\r\x12\x15\n\rjob_app_error\x18\x04 \x01(\r\x12\x15\n\rerror_details\x18\x05 \x01(\t\x12\x14\n\x0cjob_duration\x18\x06 \x01(\r\x12\x1f\n\x17\x66iles_validation_failed\x18\x07 \x01(\r\x12\x1c\n\x14job_bytes_downloaded\x18\x08 \x01(\x04\x12\x18\n\x10job_bytes_staged\x18\t \x01(\x04\x12\x16\n\x0e\x62ytes_comitted\x18\n \x01(\x04\x12\x17\n\x0fstart_app_state\x18\x0b \x01(\r\x12\x18\n\x10stats_machine_id\x18\x0c \x01(\x06\x12\x13\n\x0b\x62ranch_name\x18\r \x01(\t\x12\x1e\n\x16total_bytes_downloaded\x18\x0e \x01(\x04\x12\x1a\n\x12total_bytes_staged\x18\x0f \x01(\x04\x12\x1c\n\x14total_bytes_restored\x18\x10 \x01(\x04\x12\x13\n\x0bis_borrowed\x18\x11 \x01(\x08\x12\x17\n\x0fis_free_weekend\x18\x12 \x01(\x08\x12\x1b\n\x13total_bytes_patched\x18\x14 \x01(\x04\x12\x19\n\x11total_bytes_saved\x18\x15 \x01(\x04\x12\x0f\n\x07\x63\x65ll_id\x18\x16 \x01(\r\x12\x13\n\x0bis_workshop\x18\x17 \x01(\x08\x12\x11\n\tis_shader\x18\x18 \x01(\x08\x12\x1a\n\x12seconds_not_played\x18\x19 \x01(\r\"=\n&CDataPublisher_GetVRDeviceInfo_Request\x12\x13\n\x0bmonth_count\x18\x01 \x01(\r\"\xdd\x01\n\'CDataPublisher_GetVRDeviceInfo_Response\x12?\n\x06\x64\x65vice\x18\x01 \x03(\x0b\x32/.CDataPublisher_GetVRDeviceInfo_Response.Device\x1aq\n\x06\x44\x65vice\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03ref\x18\x02 \x01(\r\x12\x17\n\x0f\x61ggregation_ref\x18\x03 \x01(\r\x12\r\n\x05total\x18\x04 \x01(\r\x12\x0e\n\x06\x64river\x18\x05 \x01(\t\x12\x14\n\x0c\x64\x65vice_class\x18\x06 \x01(\x05\"b\n:CDataPublisher_SetVRDeviceInfoAggregationReference_Request\x12\x0b\n\x03ref\x18\x01 \x01(\r\x12\x17\n\x0f\x61ggregation_ref\x18\x02 \x01(\r\"M\n;CDataPublisher_SetVRDeviceInfoAggregationReference_Response\x12\x0e\n\x06result\x18\x01 \x01(\r\"\x8c\x01\n&CDataPublisher_AddVRDeviceInfo_Request\x12\x14\n\x0cmanufacturer\x18\x01 \x01(\t\x12\r\n\x05model\x18\x02 \x01(\t\x12\x0e\n\x06\x64river\x18\x03 \x01(\t\x12\x17\n\x0f\x63ontroller_type\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x65vice_class\x18\x05 \x01(\x05\"F\n\'CDataPublisher_AddVRDeviceInfo_Response\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x0b\n\x03ref\x18\x02 \x01(\r\"c\n(CValveHWSurvey_GetSurveySchedule_Request\x12\x17\n\x0fsurveydatetoken\x18\x01 \x01(\t\x12\x1e\n\x16surveydatetokenversion\x18\x02 \x01(\x06\"d\n)CValveHWSurvey_GetSurveySchedule_Response\x12\x17\n\x0fsurveydatetoken\x18\x01 \x01(\r\x12\x1e\n\x16surveydatetokenversion\x18\x02 \x01(\x06\x32\xc2\x04\n\rDataPublisher\x12h\n\x1d\x43lientContentCorruptionReport\x12:.CDataPublisher_ClientContentCorruptionReport_Notification\x1a\x0b.NoResponse\x12X\n\x18\x43lientUpdateAppJobReport\x12/.CDataPublisher_ClientUpdateAppJob_Notification\x1a\x0b.NoResponse\x12\x64\n\x0fGetVRDeviceInfo\x12\'.CDataPublisher_GetVRDeviceInfo_Request\x1a(.CDataPublisher_GetVRDeviceInfo_Response\x12\xa0\x01\n#SetVRDeviceInfoAggregationReference\x12;.CDataPublisher_SetVRDeviceInfoAggregationReference_Request\x1a<.CDataPublisher_SetVRDeviceInfoAggregationReference_Response\x12\x64\n\x0f\x41\x64\x64VRDeviceInfo\x12\'.CDataPublisher_AddVRDeviceInfo_Request\x1a(.CDataPublisher_AddVRDeviceInfo_Response2{\n\rValveHWSurvey\x12j\n\x11GetSurveySchedule\x12).CValveHWSurvey_GetSurveySchedule_Request\x1a*.CValveHWSurvey_GetSurveySchedule_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_datapublisher_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION._serialized_start=98
  _CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION._serialized_end=362
  _CDATAPUBLISHER_CLIENTUPDATEAPPJOB_NOTIFICATION._serialized_start=365
  _CDATAPUBLISHER_CLIENTUPDATEAPPJOB_NOTIFICATION._serialized_end=997
  _CDATAPUBLISHER_GETVRDEVICEINFO_REQUEST._serialized_start=999
  _CDATAPUBLISHER_GETVRDEVICEINFO_REQUEST._serialized_end=1060
  _CDATAPUBLISHER_GETVRDEVICEINFO_RESPONSE._serialized_start=1063
  _CDATAPUBLISHER_GETVRDEVICEINFO_RESPONSE._serialized_end=1284
  _CDATAPUBLISHER_GETVRDEVICEINFO_RESPONSE_DEVICE._serialized_start=1171
  _CDATAPUBLISHER_GETVRDEVICEINFO_RESPONSE_DEVICE._serialized_end=1284
  _CDATAPUBLISHER_SETVRDEVICEINFOAGGREGATIONREFERENCE_REQUEST._serialized_start=1286
  _CDATAPUBLISHER_SETVRDEVICEINFOAGGREGATIONREFERENCE_REQUEST._serialized_end=1384
  _CDATAPUBLISHER_SETVRDEVICEINFOAGGREGATIONREFERENCE_RESPONSE._serialized_start=1386
  _CDATAPUBLISHER_SETVRDEVICEINFOAGGREGATIONREFERENCE_RESPONSE._serialized_end=1463
  _CDATAPUBLISHER_ADDVRDEVICEINFO_REQUEST._serialized_start=1466
  _CDATAPUBLISHER_ADDVRDEVICEINFO_REQUEST._serialized_end=1606
  _CDATAPUBLISHER_ADDVRDEVICEINFO_RESPONSE._serialized_start=1608
  _CDATAPUBLISHER_ADDVRDEVICEINFO_RESPONSE._serialized_end=1678
  _CVALVEHWSURVEY_GETSURVEYSCHEDULE_REQUEST._serialized_start=1680
  _CVALVEHWSURVEY_GETSURVEYSCHEDULE_REQUEST._serialized_end=1779
  _CVALVEHWSURVEY_GETSURVEYSCHEDULE_RESPONSE._serialized_start=1781
  _CVALVEHWSURVEY_GETSURVEYSCHEDULE_RESPONSE._serialized_end=1881
  _DATAPUBLISHER._serialized_start=1884
  _DATAPUBLISHER._serialized_end=2462
  _VALVEHWSURVEY._serialized_start=2464
  _VALVEHWSURVEY._serialized_end=2587
_builder.BuildServices(DESCRIPTOR, 'steammessages_datapublisher_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steamnetworkingsockets_messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steamnetworkingsockets_messages_certs_pb2 as steamnetworkingsockets__messages__certs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%steamnetworkingsockets_messages.proto\x1a+steamnetworkingsockets_messages_certs.proto\"\x80\x02\n!CMsgSteamDatagramSessionCryptInfo\x12\x46\n\x08key_type\x18\x01 \x01(\x0e\x32+.CMsgSteamDatagramSessionCryptInfo.EKeyType:\x07INVALID\x12\x10\n\x08key_data\x18\x02 \x01(\x0c\x12\r\n\x05nonce\x18\x03 \x01(\x06\x12\x18\n\x10protocol_version\x18\x04 \x01(\r\x12/\n\x07\x63iphers\x18\x05 \x03(\x0e\x32\x1e.ESteamNetworkingSocketsCipher\"\'\n\x08\x45KeyType\x12\x0b\n\x07INVALID\x10\x00\x12\x0e\n\nCURVE25519\x10\x01\"J\n\'CMsgSteamDatagramSessionCryptInfoSigned\x12\x0c\n\x04info\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"=\n\x1b\x43MsgSteamDatagramDiagnostic\x12\x10\n\x08severity\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x8b\x02\n\'CMsgSteamDatagramLinkInstantaneousStats\x12\x1f\n\x17out_packets_per_sec_x10\x18\x01 \x01(\r\x12\x19\n\x11out_bytes_per_sec\x18\x02 \x01(\r\x12\x1e\n\x16in_packets_per_sec_x10\x18\x03 \x01(\r\x12\x18\n\x10in_bytes_per_sec\x18\x04 \x01(\r\x12\x0f\n\x07ping_ms\x18\x05 \x01(\r\x12\x1b\n\x13packets_dropped_pct\x18\x06 \x01(\r\x12\"\n\x1apackets_weird_sequence_pct\x18\x07 \x01(\r\x12\x18\n\x10peak_jitter_usec\x18\x08 \x01(\r\"\xed\n\n\"CMsgSteamDatagramLinkLifetimeStats\x12\x19\n\x11\x63onnected_seconds\x18\x02 \x01(\r\x12\x14\n\x0cpackets_sent\x18\x03 \x01(\x04\x12\x0f\n\x07kb_sent\x18\x04 \x01(\x04\x12\x14\n\x0cpackets_recv\x18\x05 \x01(\x04\x12\x0f\n\x07kb_recv\x18\x06 \x01(\x04\x12\x1e\n\x16packets_recv_sequenced\x18\x07 \x01(\x04\x12\x1c\n\x14packets_recv_dropped\x18\x08 \x01(\x04\x12!\n\x19packets_recv_out_of_order\x18\t \x01(\x04\x12+\n#packets_recv_out_of_order_corrected\x18\x0f \x01(\x04\x12\x1e\n\x16packets_recv_duplicate\x18\n \x01(\x04\x12\x1a\n\x12packets_recv_lurch\x18\x0b \x01(\x04\x12(\n multipath_packets_recv_sequenced\x18\x0c \x03(\x04\x12$\n\x1cmultipath_packets_recv_later\x18\r \x03(\x04\x12\x1e\n\x16multipath_send_enabled\x18\x0e \x01(\r\x12\x1d\n\x15quality_histogram_100\x18\x15 \x01(\r\x12\x1c\n\x14quality_histogram_99\x18\x16 \x01(\r\x12\x1c\n\x14quality_histogram_97\x18\x17 \x01(\r\x12\x1c\n\x14quality_histogram_95\x18\x18 \x01(\r\x12\x1c\n\x14quality_histogram_90\x18\x19 \x01(\r\x12\x1c\n\x14quality_histogram_75\x18\x1a \x01(\r\x12\x1c\n\x14quality_histogram_50\x18\x1b \x01(\r\x12\x1b\n\x13quality_histogram_1\x18\x1c \x01(\r\x12\x1e\n\x16quality_histogram_dead\x18\x1d \x01(\r\x12\x19\n\x11quality_ntile_2nd\x18\x1e \x01(\r\x12\x19\n\x11quality_ntile_5th\x18\x1f \x01(\r\x12\x1a\n\x12quality_ntile_25th\x18  \x01(\r\x12\x1a\n\x12quality_ntile_50th\x18! \x01(\r\x12\x19\n\x11ping_histogram_25\x18) \x01(\r\x12\x19\n\x11ping_histogram_50\x18* \x01(\r\x12\x19\n\x11ping_histogram_75\x18+ \x01(\r\x12\x1a\n\x12ping_histogram_100\x18, \x01(\r\x12\x1a\n\x12ping_histogram_125\x18- \x01(\r\x12\x1a\n\x12ping_histogram_150\x18. \x01(\r\x12\x1a\n\x12ping_histogram_200\x18/ \x01(\r\x12\x1a\n\x12ping_histogram_300\x18\x30 \x01(\r\x12\x1a\n\x12ping_histogram_max\x18\x31 \x01(\r\x12\x16\n\x0eping_ntile_5th\x18\x32 \x01(\r\x12\x17\n\x0fping_ntile_50th\x18\x33 \x01(\r\x12\x17\n\x0fping_ntile_75th\x18\x34 \x01(\r\x12\x17\n\x0fping_ntile_95th\x18\x35 \x01(\r\x12\x17\n\x0fping_ntile_98th\x18\x36 \x01(\r\x12#\n\x1bjitter_histogram_negligible\x18= \x01(\r\x12\x1a\n\x12jitter_histogram_1\x18> \x01(\r\x12\x1a\n\x12jitter_histogram_2\x18? \x01(\r\x12\x1a\n\x12jitter_histogram_5\x18@ \x01(\r\x12\x1b\n\x13jitter_histogram_10\x18\x41 \x01(\r\x12\x1b\n\x13jitter_histogram_20\x18\x42 \x01(\r\"\x9c\x01\n\"CMsgSteamDatagramConnectionQuality\x12?\n\rinstantaneous\x18\x01 \x01(\x0b\x32(.CMsgSteamDatagramLinkInstantaneousStats\x12\x35\n\x08lifetime\x18\x02 \x01(\x0b\x32#.CMsgSteamDatagramLinkLifetimeStats\"%\n\x10\x43MsgICECandidate\x12\x11\n\tcandidate\x18\x03 \x01(\t\"~\n\x11\x43MsgICERendezvous\x12%\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x17.CMsgICERendezvous.Auth\x12(\n\radd_candidate\x18\x01 \x01(\x0b\x32\x11.CMsgICECandidate\x1a\x18\n\x04\x41uth\x12\x10\n\x08pwd_frag\x18\x01 \x01(\t\"\xa3\t\n CMsgSteamNetworkingP2PRendezvous\x12\x15\n\rfrom_identity\x18\x08 \x01(\t\x12\x1a\n\x12\x66rom_connection_id\x18\t \x01(\x07\x12\x13\n\x0bto_identity\x18\n \x01(\t\x12\x18\n\x10to_connection_id\x18\x01 \x01(\x07\x12\x12\n\nsdr_routes\x18\x02 \x01(\x0c\x12 \n\x18\x61\x63k_peer_routes_revision\x18\x03 \x01(\r\x12\x13\n\x0bice_enabled\x18\x07 \x01(\x08\x12\x1c\n\x14hosted_server_ticket\x18\x0e \x01(\x0c\x12I\n\x0f\x63onnect_request\x18\x04 \x01(\x0b\x32\x30.CMsgSteamNetworkingP2PRendezvous.ConnectRequest\x12?\n\nconnect_ok\x18\x05 \x01(\x0b\x32+.CMsgSteamNetworkingP2PRendezvous.ConnectOK\x12M\n\x11\x63onnection_closed\x18\x06 \x01(\x0b\x32\x32.CMsgSteamNetworkingP2PRendezvous.ConnectionClosed\x12\x18\n\x10\x61\x63k_reliable_msg\x18\x0b \x01(\r\x12\x1a\n\x12\x66irst_reliable_msg\x18\x0c \x01(\r\x12L\n\x11reliable_messages\x18\r \x03(\x0b\x32\x31.CMsgSteamNetworkingP2PRendezvous.ReliableMessage\x12R\n\x14\x61pplication_messages\x18\x0f \x03(\x0b\x32\x34.CMsgSteamNetworkingP2PRendezvous.ApplicationMessage\x1a\xc5\x01\n\x0e\x43onnectRequest\x12\x37\n\x05\x63rypt\x18\x06 \x01(\x0b\x32(.CMsgSteamDatagramSessionCryptInfoSigned\x12\x31\n\x04\x63\x65rt\x18\x07 \x01(\x0b\x32#.CMsgSteamDatagramCertificateSigned\x12\x17\n\x0fto_virtual_port\x18\t \x01(\r\x12\x19\n\x11\x66rom_virtual_port\x18\n \x01(\r\x12\x13\n\x0b\x66rom_fakeip\x18\x0b \x01(\t\x1aw\n\tConnectOK\x12\x37\n\x05\x63rypt\x18\x05 \x01(\x0b\x32(.CMsgSteamDatagramSessionCryptInfoSigned\x12\x31\n\x04\x63\x65rt\x18\x06 \x01(\x0b\x32#.CMsgSteamDatagramCertificateSigned\x1a\x36\n\x10\x43onnectionClosed\x12\r\n\x05\x64\x65\x62ug\x18\x05 \x01(\t\x12\x13\n\x0breason_code\x18\x06 \x01(\r\x1a\x32\n\x0fReliableMessage\x12\x1f\n\x03ice\x18\x01 \x01(\x0b\x32\x12.CMsgICERendezvous\x1aT\n\x12\x41pplicationMessage\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0f\n\x07msg_num\x18\x02 \x01(\x04\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x10\n\x08lane_idx\x18\x04 \x01(\r\"\xa6\x03\n$CMsgSteamNetworkingICESessionSummary\x12\x1b\n\x13\x66\x61ilure_reason_code\x18\x07 \x01(\r\x12\x1d\n\x15local_candidate_types\x18\x01 \x01(\r\x12\x1e\n\x16remote_candidate_types\x18\x02 \x01(\r\x12\x1a\n\x12initial_route_kind\x18\x03 \x01(\r\x12\x14\n\x0cinitial_ping\x18\x04 \x01(\r\x12\x15\n\rinitial_score\x18\x06 \x01(\r\x12\x16\n\x0enegotiation_ms\x18\x05 \x01(\r\x12\x17\n\x0f\x62\x65st_route_kind\x18\x10 \x01(\r\x12\x11\n\tbest_ping\x18\x11 \x01(\r\x12\x12\n\nbest_score\x18\x12 \x01(\r\x12\x11\n\tbest_time\x18\x13 \x01(\r\x12\x18\n\x10selected_seconds\x18\x0c \x01(\r\x12\x15\n\ruser_settings\x18\r \x01(\r\x12\x16\n\x0eice_enable_var\x18\x0e \x01(\r\x12%\n\x1dlocal_candidate_types_allowed\x18\x0f \x01(\r*\xa7\x01\n\x1d\x45SteamNetworkingSocketsCipher\x12+\n\'k_ESteamNetworkingSocketsCipher_INVALID\x10\x00\x12(\n$k_ESteamNetworkingSocketsCipher_NULL\x10\x01\x12/\n+k_ESteamNetworkingSocketsCipher_AES_256_GCM\x10\x02\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steamnetworkingsockets_messages_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _ESTEAMNETWORKINGSOCKETSCIPHER._serialized_start=4088
  _ESTEAMNETWORKINGSOCKETSCIPHER._serialized_end=4255
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFO._serialized_start=87
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFO._serialized_end=343
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFO_EKEYTYPE._serialized_start=304
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFO_EKEYTYPE._serialized_end=343
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFOSIGNED._serialized_start=345
  _CMSGSTEAMDATAGRAMSESSIONCRYPTINFOSIGNED._serialized_end=419
  _CMSGSTEAMDATAGRAMDIAGNOSTIC._serialized_start=421
  _CMSGSTEAMDATAGRAMDIAGNOSTIC._serialized_end=482
  _CMSGSTEAMDATAGRAMLINKINSTANTANEOUSSTATS._serialized_start=485
  _CMSGSTEAMDATAGRAMLINKINSTANTANEOUSSTATS._serialized_end=752
  _CMSGSTEAMDATAGRAMLINKLIFETIMESTATS._serialized_start=755
  _CMSGSTEAMDATAGRAMLINKLIFETIMESTATS._serialized_end=2144
  _CMSGSTEAMDATAGRAMCONNECTIONQUALITY._serialized_start=2147
  _CMSGSTEAMDATAGRAMCONNECTIONQUALITY._serialized_end=2303
  _CMSGICECANDIDATE._serialized_start=2305
  _CMSGICECANDIDATE._serialized_end=2342
  _CMSGICERENDEZVOUS._serialized_start=2344
  _CMSGICERENDEZVOUS._serialized_end=2470
  _CMSGICERENDEZVOUS_AUTH._serialized_start=2446
  _CMSGICERENDEZVOUS_AUTH._serialized_end=2470
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS._serialized_start=2473
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS._serialized_end=3660
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTREQUEST._serialized_start=3148
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTREQUEST._serialized_end=3345
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTOK._serialized_start=3347
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTOK._serialized_end=3466
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTIONCLOSED._serialized_start=3468
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_CONNECTIONCLOSED._serialized_end=3522
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_RELIABLEMESSAGE._serialized_start=3524
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_RELIABLEMESSAGE._serialized_end=3574
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_APPLICATIONMESSAGE._serialized_start=3576
  _CMSGSTEAMNETWORKINGP2PRENDEZVOUS_APPLICATIONMESSAGE._serialized_end=3660
  _CMSGSTEAMNETWORKINGICESESSIONSUMMARY._serialized_start=3663
  _CMSGSTEAMNETWORKINGICESESSIONSUMMARY._serialized_end=4085
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_shader.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asteammessages_shader.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"+\n)CShader_GetShaderReportingCadence_Request\"j\n*CShader_GetShaderReportingCadence_Response\x12\x1f\n\x17rereport_time_threshold\x18\x01 \x01(\x04\x12\x1b\n\x13percent_to_rereport\x18\x02 \x01(\r\"\xc9\x01\n\x1e\x43Shader_RegisterShader_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08gpu_desc\x18\x02 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x03 \x01(\t\x12\x37\n\x07shaders\x18\x04 \x03(\x0b\x32&.CShader_RegisterShader_Request.Shader\x1a\x38\n\x06Shader\x12\x15\n\rcache_key_sha\x18\x01 \x01(\x0c\x12\x17\n\x0fshader_code_sha\x18\x02 \x01(\x0c\"<\n\x1f\x43Shader_RegisterShader_Response\x12\x19\n\x11requested_codeids\x18\x01 \x03(\r\"\xa0\x01\n\x1a\x43Shader_SendShader_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x37\n\x07shaders\x18\x02 \x03(\x0b\x32&.CShader_SendShader_Request.ShaderCode\x1a:\n\nShaderCode\x12\x17\n\x0fshader_code_sha\x18\x01 \x01(\x0c\x12\x13\n\x0bshader_code\x18\x02 \x01(\x0c\"\x1d\n\x1b\x43Shader_SendShader_Response\"Y\n!CShader_GetBucketManifest_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08gpu_desc\x18\x02 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x03 \x01(\t\"]\n\"CShader_GetBucketManifest_Response\x12\x12\n\nmanifestid\x18\x01 \x01(\x04\x12\x11\n\tdepotsize\x18\x02 \x01(\x04\x12\x10\n\x08\x62ucketid\x18\x03 \x01(\x04\"G\n\x1e\x43Shader_GetStaleBucket_Request\x12\x10\n\x08gpu_desc\x18\x01 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x02 \x01(\t\"\x9b\x01\n\x1f\x43Shader_GetStaleBucket_Response\x12\x10\n\x08\x62ucketid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x12\n\nmanifestid\x18\x03 \x01(\x04\x12\x10\n\x08gpu_desc\x18\x04 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x05 \x01(\t\x12\x1c\n\x14\x64\x65pot_encryption_key\x18\x06 \x01(\x0c\"\xb7\x01\n#CShader_ReportExternalBuild_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08gpu_desc\x18\x02 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x03 \x01(\t\x12\x12\n\nmanifestid\x18\x04 \x01(\x04\x12\x17\n\x0fsource_gpu_desc\x18\x05 \x01(\t\x12\x1a\n\x12source_driver_desc\x18\x06 \x01(\t\x12\x11\n\tdepotsize\x18\x07 \x01(\x04\"&\n$CShader_ReportExternalBuild_Response2\xb3\x04\n\x06Shader\x12t\n\x19GetShaderReportingCadence\x12*.CShader_GetShaderReportingCadence_Request\x1a+.CShader_GetShaderReportingCadence_Response\x12S\n\x0eRegisterShader\x12\x1f.CShader_RegisterShader_Request\x1a .CShader_RegisterShader_Response\x12G\n\nSendShader\x12\x1b.CShader_SendShader_Request\x1a\x1c.CShader_SendShader_Response\x12\\\n\x11GetBucketManifest\x12\".CShader_GetBucketManifest_Request\x1a#.CShader_GetBucketManifest_Response\x12S\n\x0eGetStaleBucket\x12\x1f.CShader_GetStaleBucket_Request\x1a .CShader_GetStaleBucket_Response\x12\x62\n\x13ReportExternalBuild\x12$.CShader_ReportExternalBuild_Request\x1a%.CShader_ReportExternalBuild_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_shader_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CSHADER_GETSHADERREPORTINGCADENCE_REQUEST._serialized_start=90
  _CSHADER_GETSHADERREPORTINGCADENCE_REQUEST._serialized_end=133
  _CSHADER_GETSHADERREPORTINGCADENCE_RESPONSE._serialized_start=135
  _CSHADER_GETSHADERREPORTINGCADENCE_RESPONSE._serialized_end=241
  _CSHADER_REGISTERSHADER_REQUEST._serialized_start=244
  _CSHADER_REGISTERSHADER_REQUEST._serialized_end=445
  _CSHADER_REGISTERSHADER_REQUEST_SHADER._serialized_start=389
  _CSHADER_REGISTERSHADER_REQUEST_SHADER._serialized_end=445
  _CSHADER_REGISTERSHADER_RESPONSE._serialized_start=447
  _CSHADER_REGISTERSHADER_RESPONSE._serialized_end=507
  _CSHADER_SENDSHADER_REQUEST._serialized_start=510
  _CSHADER_SENDSHADER_REQUEST._serialized_end=670
  _CSHADER_SENDSHADER_REQUEST_SHADERCODE._serialized_start=612
  _CSHADER_SENDSHADER_REQUEST_SHADERCODE._serialized_end=670
  _CSHADER_SENDSHADER_RESPONSE._serialized_start=672
  _CSHADER_SENDSHADER_RESPONSE._serialized_end=701
  _CSHADER_GETBUCKETMANIFEST_REQUEST._serialized_start=703
  _CSHADER_GETBUCKETMANIFEST_REQUEST._serialized_end=792
  _CSHADER_GETBUCKETMANIFEST_RESPONSE._serialized_start=794
  _CSHADER_GETBUCKETMANIFEST_RESPONSE._serialized_end=887
  _CSHADER_GETSTALEBUCKET_REQUEST._serialized_start=889
  _CSHADER_GETSTALEBUCKET_REQUEST._serialized_end=960
  _CSHADER_GETSTALEBUCKET_RESPONSE._serialized_start=963
  _CSHADER_GETSTALEBUCKET_RESPONSE._serialized_end=1118
  _CSHADER_REPORTEXTERNALBUILD_REQUEST._serialized_start=1121
  _CSHADER_REPORTEXTERNALBUILD_REQUEST._serialized_end=1304
  _CSHADER_REPORTEXTERNALBUILD_RESPONSE._serialized_start=1306
  _CSHADER_REPORTEXTERNALBUILD_RESPONSE._serialized_end=1344
  _SHADER._serialized_start=1347
  _SHADER._serialized_end=1910
_builder.BuildServices(DESCRIPTOR, 'steammessages_shader_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: htmlmessages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12htmlmessages.proto\x1a\x0b\x65nums.proto\"^\n\tCMsgKeyUp\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07keyCode\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\x12\x15\n\rnativeKeyCode\x18\x04 \x01(\r\"w\n\x0b\x43MsgKeyDown\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07keyCode\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\x12\x15\n\ris_system_key\x18\x04 \x01(\x08\x12\x15\n\rnativeKeyCode\x18\x05 \x01(\r\"q\n\x0b\x43MsgKeyChar\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07unichar\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\x12\x0f\n\x07keyCode\x18\x04 \x01(\r\x12\x15\n\rnativeKeyCode\x18\x05 \x01(\r\"P\n\rCMsgMouseDown\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x14\n\x0cmouse_button\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\"z\n\x0b\x43MsgMouseUp\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x14\n\x0cmouse_button\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\x12\x14\n\x0cis_off_panel\x18\x04 \x01(\x08\x12\t\n\x01x\x18\x05 \x01(\x05\x12\t\n\x01y\x18\x06 \x01(\x05\"T\n\x11\x43MsgMouseDblClick\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x14\n\x0cmouse_button\x18\x02 \x01(\r\x12\x11\n\tmodifiers\x18\x03 \x01(\r\"[\n\x0e\x43MsgMouseWheel\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06\x64\x65ltax\x18\x02 \x01(\x05\x12\x0e\n\x06\x64\x65ltay\x18\x03 \x01(\x05\x12\x11\n\tmodifiers\x18\x04 \x01(\r\"P\n\rCMsgMouseMove\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x05\x12\t\n\x01y\x18\x03 \x01(\x05\x12\x11\n\tmodifiers\x18\x04 \x01(\r\"(\n\x0e\x43MsgMouseLeave\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\xdd\x03\n\x11\x43MsgBrowserCreate\x12\x12\n\nrequest_id\x18\x01 \x01(\r\x12\x11\n\tuseragent\x18\x03 \x01(\t\x12\x10\n\x08user_css\x18\x05 \x01(\t\x12\x18\n\x10native_dropdowns\x18\x06 \x01(\x08\x12\x13\n\x0b\x64pi_scaling\x18\x07 \x01(\x02\x12\x17\n\toffscreen\x18\x08 \x01(\x08:\x04true\x12\x18\n\rinitial_width\x18\t \x01(\r:\x01\x30\x12\x19\n\x0einitial_height\x18\n \x01(\r:\x01\x30\x12\x13\n\x0bwindow_icon\x18\x0b \x01(\t\x12\x19\n\nborderless\x18\x0c \x01(\x08:\x05\x66\x61lse\x12\x15\n\rvroverlay_key\x18\r \x01(\t\x12\x17\n\x0c\x62rowser_type\x18\x0e \x01(\r:\x01\x30\x12 \n\x0binitial_top\x18\x0f \x01(\x05:\x0b-2147483648\x12!\n\x0cinitial_left\x18\x10 \x01(\x05:\x0b-2147483648\x12(\n\x19only_allow_trusted_popups\x18\x11 \x01(\x08:\x05\x66\x61lse\x12\x13\n\x0binitial_url\x18\x12 \x01(\t\x12\x13\n\x0bhwnd_parent\x18\x13 \x01(\x06\x12\x19\n\x0e\x63reation_flags\x18\x14 \x01(\r:\x01\x30\"G\n\x19\x43MsgBrowserCreateResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x12\n\nrequest_id\x18\x02 \x01(\r\"+\n\x11\x43MsgBrowserRemove\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\x98\x02\n\x1e\x43MsgSetLocalFileRequestMapping\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x13\n\x0brequest_url\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x65\x66\x61ult_local_path\x18\x03 \x01(\t\x12?\n\x06routes\x18\x04 \x03(\x0b\x32/.CMsgSetLocalFileRequestMapping.AdditionalRoute\x1al\n\x0f\x41\x64\x64itionalRoute\x12\x14\n\x0crelative_url\x18\x01 \x01(\t\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12\x1a\n\x12\x61llowed_extensions\x18\x03 \x01(\t\x12\x13\n\x0burl_rewrite\x18\x04 \x01(\x08\"\xb9\x01\n\x17\x43MsgBrowserErrorStrings\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06header\x18\x03 \x01(\t\x12\x12\n\ncache_miss\x18\x04 \x01(\t\x12\x0f\n\x07\x62\x61\x64_url\x18\x05 \x01(\t\x12\x1a\n\x12\x63onnection_problem\x18\x06 \x01(\t\x12\x15\n\rproxy_problem\x18\x07 \x01(\t\x12\x0f\n\x07unknown\x18\x08 \x01(\t\":\n\x12\x43MsgBrowserSetName\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"H\n\x0f\x43MsgBrowserSize\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\x01\x12\x0e\n\x06height\x18\x03 \x01(\x01\"N\n\x15\x43MsgBrowserSetMinSize\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\x01\x12\x0e\n\x06height\x18\x03 \x01(\x01\"e\n\x13\x43MsgBrowserPosition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\x0f\n\x07x_local\x18\x04 \x01(\x01\x12\x0f\n\x07y_local\x18\x05 \x01(\x01\"\xe8\x01\n\x12\x43MsgBrowserResized\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\r\n\x05width\x18\x04 \x01(\x01\x12\x0e\n\x06height\x18\x05 \x01(\x01\x12\x12\n\nfullscreen\x18\x06 \x01(\x08\x12\x16\n\x0e\x64pi_horizontal\x18\x07 \x01(\x01\x12\x14\n\x0c\x64pi_vertical\x18\x08 \x01(\x01\x12\x14\n\x0c\x64isplay_name\x18\t \x01(\t\x12\x15\n\rdisplay_width\x18\n \x01(\r\x12\x16\n\x0e\x64isplay_height\x18\x0b \x01(\r\"k\n\x0b\x43MsgPostURL\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04post\x18\x03 \x01(\t\x12\x12\n\npageserial\x18\x04 \x01(\r\x12\x15\n\rreplace_entry\x18\x05 \x01(\x08\"t\n\rCMsgAddHeader\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x1a\n\x12only_send_to_steam\x18\x04 \x01(\x08\x12\x13\n\x0bsend_in_xhr\x18\x05 \x01(\x08\"&\n\x0c\x43MsgStopLoad\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"$\n\nCMsgReload\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\'\n\rCMsgGoForward\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"$\n\nCMsgGoBack\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"7\n\rCMsgWasHidden\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06hidden\x18\x02 \x01(\x08\"B\n\x17\x43MsgSetWindowVisibility\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07visible\x18\x02 \x01(\x08\"*\n\x10\x43MsgClearHistory\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"2\n\x18\x43MsgClearAllBrowsingData\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\"\n\x08\x43MsgCopy\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"#\n\tCMsgPaste\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"?\n\x15\x43MsgExecuteJavaScript\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06script\x18\x02 \x01(\t\"5\n\x0c\x43MsgSetFocus\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05\x66ocus\x18\x02 \x01(\x08\"5\n\x1b\x43MsgHorizontalScrollBarSize\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\x93\x01\n#CMsgHorizontalScrollBarSizeResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x12\n\nscroll_max\x18\x06 \x01(\r\x12\x0e\n\x06scroll\x18\x07 \x01(\r\x12\x0c\n\x04zoom\x18\x08 \x01(\x02\x12\x0f\n\x07visible\x18\t \x01(\x08\x12\x11\n\tpage_size\x18\n \x01(\r\"3\n\x19\x43MsgVerticalScrollBarSize\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\x91\x01\n!CMsgVerticalScrollBarSizeResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x12\n\nscroll_max\x18\x06 \x01(\r\x12\x0e\n\x06scroll\x18\x07 \x01(\r\x12\x0c\n\x04zoom\x18\x08 \x01(\x02\x12\x0f\n\x07visible\x18\t \x01(\x08\x12\x11\n\tpage_size\x18\n \x01(\r\"X\n\x08\x43MsgFind\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04\x66ind\x18\x02 \x01(\t\x12\x0e\n\x06infind\x18\x03 \x01(\x08\x12\x16\n\x07reverse\x18\x04 \x01(\x08:\x05\x66\x61lse\"&\n\x0c\x43MsgStopFind\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"A\n\x17\x43MsgSetHorizontalScroll\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06scroll\x18\x02 \x01(\r\"?\n\x15\x43MsgSetVerticalScroll\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06scroll\x18\x02 \x01(\r\"8\n\x10\x43MsgSetZoomLevel\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04zoom\x18\x02 \x01(\x01\"(\n\x0e\x43MsgViewSource\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"X\n\x10\x43MsgBrowserReady\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x16\n\x0evr_overlay_key\x18\x02 \x01(\t\x12\x14\n\x0chwnd_browser\x18\x03 \x01(\x06\"\x87\x01\n\x0e\x43MsgURLChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x10\n\x08postData\x18\x03 \x01(\t\x12\x13\n\x0b\x62IsRedirect\x18\x04 \x01(\x08\x12\x11\n\tpagetitle\x18\x05 \x01(\t\x12\x16\n\x0e\x62NewNavigation\x18\x06 \x01(\x08\"\x1c\n\rCHistoryEntry\x12\x0b\n\x03url\x18\x01 \x01(\t\"\\\n\x12\x43MsgHistoryChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05index\x18\x02 \x01(\r\x12\x1f\n\x07\x65ntries\x18\x03 \x03(\x0b\x32\x0e.CHistoryEntry\"c\n\rCMsgLoadError\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x12\n\nerror_code\x18\x02 \x01(\x05\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x19\n\x11\x65rror_description\x18\x04 \x01(\t\")\n\x0b\x43HTMLHeader\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xbc\x01\n\x15\x43HTMLPageSecurityInfo\x12\x18\n\tbIsSecure\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\rbHasCertError\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x12\n\nissuerName\x18\x03 \x01(\t\x12\x10\n\x08\x63\x65rtName\x18\x04 \x01(\t\x12\x15\n\ncertExpiry\x18\x05 \x01(\x05:\x01\x30\x12\x14\n\tnCertBits\x18\x06 \x01(\x05:\x01\x30\x12\x18\n\tbIsEVCert\x18\x07 \x01(\x08:\x05\x66\x61lse\"M\n\x13\x43MsgFinishedRequest\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x11\n\tpageTitle\x18\x03 \x01(\t\"j\n\x11\x43MsgLoadedRequest\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x11\n\tpageTitle\x18\x03 \x01(\t\x12\x1d\n\x07headers\x18\x05 \x03(\x0b\x32\x0c.CHTMLHeader\"=\n\x15\x43MsgFavIconURLChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04urls\x18\x02 \x03(\t\"f\n\x10\x43MsgPageSecurity\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12-\n\rsecurity_info\x18\x03 \x01(\x0b\x32\x16.CHTMLPageSecurityInfo\"n\n\x10\x43MsgStartRequest\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\x12\x10\n\x08postData\x18\x04 \x01(\t\x12\x13\n\x0b\x62IsRedirect\x18\x05 \x01(\x08\"B\n\x18\x43MsgStartRequestResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06\x62\x41llow\x18\x02 \x01(\x08\"\'\n\rCMsgShowPopup\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\'\n\rCMsgHidePopup\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"Y\n\rCMsgSizePopup\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x05\x12\t\n\x01y\x18\x03 \x01(\x05\x12\x0c\n\x04wide\x18\x04 \x01(\r\x12\x0c\n\x04tall\x18\x05 \x01(\r\"J\n\x0e\x43MsgOpenNewTab\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x46oreground\x18\x03 \x01(\x08\"\x84\x02\n\x13\x43MsgPopupHTMLWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x16\n\x01x\x18\x03 \x01(\x05:\x0b-2147483648\x12\x16\n\x01y\x18\x04 \x01(\x05:\x0b-2147483648\x12\x0c\n\x04wide\x18\x05 \x01(\r\x12\x0c\n\x04tall\x18\x06 \x01(\r\x12\x13\n\x0bpopup_index\x18\x07 \x01(\r\x12\x17\n\x0ftrusted_creator\x18\x08 \x01(\x08\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0c\n\x04hwnd\x18\n \x01(\x04\x12\x1a\n\x12parent_popup_index\x18\x0b \x01(\r\x12\x16\n\x0e\x63reation_flags\x18\x0c \x01(\r\"E\n\x1b\x43MsgPopupHTMLWindowResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06\x62\x41llow\x18\x02 \x01(\x08\"9\n\x10\x43MsgSetHTMLTitle\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05title\x18\x02 \x01(\t\":\n\x13\x43MsgLoadingResource\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\"6\n\x0e\x43MsgStatusText\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x8c\x01\n\rCMsgSetCursor\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06\x63ursor\x18\x02 \x01(\r\x12\x13\n\x0b\x63ustom_data\x18\x03 \x01(\x0c\x12\x0c\n\x04wide\x18\x04 \x01(\r\x12\x0c\n\x04tall\x18\x05 \x01(\r\x12\x10\n\x08xhotspot\x18\x06 \x01(\r\x12\x10\n\x08yhotspot\x18\x07 \x01(\r\"\x9b\x02\n\x12\x43MsgFileLoadDialog\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0binitialFile\x18\x04 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65pt_types\x18\x05 \x03(\t\x12\x0f\n\x07is_save\x18\x06 \x01(\x08\x12\x18\n\x10\x63hoose_directory\x18\x07 \x01(\x08\x12+\n\x07\x66ilters\x18\x08 \x03(\x0b\x32\x1a.CMsgFileLoadDialog.Filter\x1a<\n\x06\x46ilter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08patterns\x18\x02 \x03(\t\x12\x12\n\nis_default\x18\x03 \x01(\x08\"t\n\x1a\x43MsgFileLoadDialogResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x10\n\x08\x62success\x18\x03 \x01(\x08\x12\r\n\x05\x66iles\x18\x04 \x03(\t\"+\n\x16\x43MsgRequestProcessInfo\x12\x11\n\trequestid\x18\x01 \x01(\x04\"\xeb\n\n\x1b\x43MsgProcessInfoNotification\x12\x11\n\trequestid\x18\x01 \x01(\x04\x12\x43\n\ngpu_status\x18\x02 \x01(\x0e\x32\x12.EBrowserGPUStatus:\x1bk_EBrowserGPUStatus_Invalid\x12J\n\tcanvas_2d\x18\x03 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12Y\n\x18\x63\x61nvas_oop_rasterization\x18\x04 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12\x64\n#direct_rendering_display_compositor\x18\x05 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12P\n\x0fgpu_compositing\x18\x06 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12X\n\x17multiple_raster_threads\x18\x07 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12G\n\x06opengl\x18\x08 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12N\n\rrasterization\x18\t \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12I\n\x08raw_draw\x18\n \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12N\n\rskia_graphite\x18\x0b \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12M\n\x0cvideo_decode\x18\r \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12M\n\x0cvideo_encode\x18\x0e \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12G\n\x06vulkan\x18\x0f \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12\x46\n\x05webgl\x18\x10 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12G\n\x06webgl2\x18\x11 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12G\n\x06webgpu\x18\x12 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\x12\x46\n\x05webnn\x18\x13 \x01(\x0e\x32\x16.EBrowserFeatureStatus:\x1fk_EBrowserFeatureStatus_Invalid\"7\n\x0f\x43MsgShowToolTip\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"9\n\x11\x43MsgUpdateToolTip\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\")\n\x0f\x43MsgHideToolTip\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"Q\n\x11\x43MsgSearchResults\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x13\n\x0b\x61\x63tiveMatch\x18\x02 \x01(\x05\x12\x0f\n\x07results\x18\x03 \x01(\x05\"#\n\tCMsgClose\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\x8a\x01\n\x19\x43MsgSetSharedPaintBuffers\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04wide\x18\x02 \x01(\r\x12\x0c\n\x04tall\x18\x03 \x01(\r\x12\x12\n\nsource_pid\x18\x04 \x01(\x04\x12\x15\n\rsource_handle\x18\x05 \x01(\x04\x12\x0e\n\x06handle\x18\x06 \x01(\x04\"3\n\x19\x43MsgAckSharedPaintBuffers\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\xbb\x01\n\x0e\x43MsgNeedsPaint\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07scrollx\x18\n \x01(\r\x12\x0f\n\x07scrolly\x18\x0b \x01(\r\x12\x11\n\tpagescale\x18\x0c \x01(\x02\x12\x12\n\npageserial\x18\x0f \x01(\r\x12\x14\n\x0c\x61vg_frame_ms\x18\x14 \x01(\r\x12\x1b\n\x13stddev_sum_frame_ms\x18\x15 \x01(\x02\x12\x15\n\rlong_frame_ms\x18\x16 \x01(\r\"\xaf\x01\n\x13\x43MsgComboNeedsPaint\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04rgba\x18\x02 \x01(\x04\x12\x18\n\rcombobox_wide\x18\x03 \x01(\r:\x01\x30\x12\x18\n\rcombobox_tall\x18\x04 \x01(\r:\x01\x30\x12\x1f\n\x14shared_memory_handle\x18\x05 \x01(\x04:\x01\x30\x12\x1d\n\x12shared_memory_size\x18\x07 \x01(\x04:\x01\x30\"\xb3\x01\n\x1b\x43MsgNeedsSharedTexturePaint\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x14\n\x0cshare_handle\x18\x02 \x01(\r\x12\r\n\x05width\x18\x03 \x01(\r\x12\x0e\n\x06height\x18\x04 \x01(\r\x12\x0f\n\x07scrollx\x18\x05 \x01(\r\x12\x0f\n\x07scrolly\x18\x06 \x01(\r\x12\x11\n\tpagescale\x18\x07 \x01(\x02\x12\x12\n\npageserial\x18\x08 \x01(\r\"%\n\x0b\x43MsgGetZoom\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\";\n\x13\x43MsgGetZoomResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04zoom\x18\x02 \x01(\x02\"B\n\x12\x43MsgLinkAtPosition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\"z\n\x1a\x43MsgLinkAtPositionResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x11\n\tblivelink\x18\x05 \x01(\x08\x12\x0e\n\x06\x62input\x18\x06 \x01(\x08\"K\n\x1b\x43MsgZoomToElementAtPosition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\"^\n#CMsgZoomToElementAtPositionResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05scale\x18\x02 \x01(\x02\x12\x10\n\x08\x64uration\x18\x03 \x01(\x02\"S\n\x14\x43MsgScalePageToValue\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05scale\x18\x02 \x01(\x02\x12\t\n\x01x\x18\x03 \x01(\x02\x12\t\n\x01y\x18\x04 \x01(\x02\"W\n\x1b\x43MsgForcePopupsToDirectHWND\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12 \n\x18\x66orce_direct_hwnd_popups\x18\x02 \x01(\x08\"D\n\x1c\x43MsgScalePageToValueResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04zoom\x18\x02 \x01(\x02\"j\n\x12\x43MsgSavePageToJPEG\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\r\n\x05width\x18\x04 \x01(\r\x12\x0e\n\x06height\x18\x05 \x01(\r\"S\n\x1a\x43MsgSavePageToJPEGResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\"6\n\x0b\x43MsgJSAlert\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\"8\n\rCMsgJSConfirm\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\">\n\x14\x43MsgJSDialogResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06result\x18\x02 \x01(\x08\"V\n\x17\x43MsgCanGoBackAndForward\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07\x62goback\x18\x02 \x01(\x08\x12\x12\n\nbgoforward\x18\x03 \x01(\x08\"I\n\x10\x43MsgOpenSteamURL\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x10\n\x08referrer\x18\x03 \x01(\t\"\x8c\x01\n\rCMsgSetCookie\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04host\x18\x04 \x01(\t\x12\x0f\n\x07\x65xpires\x18\x05 \x01(\r\x12\x0e\n\x06secure\x18\x06 \x01(\x08\x12\x10\n\x08httponly\x18\x07 \x01(\x08\x12\x10\n\x08samesite\x18\x08 \x01(\x05\"J\n\x16\x43MsgSetTargetFrameRate\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x18\n\x10nTargetFrameRate\x18\x02 \x01(\r\"*\n\x10\x43MsgPauseRepaint\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\")\n\x0f\x43MsgFullRepaint\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"/\n\x15\x43MsgRequestFullScreen\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\",\n\x12\x43MsgExitFullScreen\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"4\n\x1a\x43MsgToggleFindInPageDialog\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"0\n\x16\x43MsgSetPIDShuttingDown\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"9\n\x1f\x43MsgDisableBackgroundThrottling\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"0\n\x16\x43MsgAckPIDShuttingDown\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\";\n\x14\x43MsgGetCookiesForURL\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\"D\n\x07\x43\x43ookie\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\"^\n\x1c\x43MsgGetCookiesForURLResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x19\n\x07\x63ookies\x18\x03 \x03(\x0b\x32\x08.CCookie\"\xc0\x01\n\x10\x43MsgNodeHasFocus\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0e\n\x06\x62Input\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x16\n\x0e\x65lementtagname\x18\x04 \x01(\t\x12\x18\n\x10searchbuttontext\x18\x05 \x01(\t\x12\x1a\n\x12\x62HasMultipleInputs\x18\x06 \x01(\x08\x12\x12\n\ninput_type\x18\x07 \x01(\t\x12\x14\n\x0c\x62IsMainFrame\x18\x08 \x01(\x08\"2\n\x18\x43MsgZoomToFocusedElement\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"-\n\x13\x43MsgFocusedNodeText\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"D\n\x1b\x43MsgFocusedNodeTextResponse\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\t\"\x1f\n\x0b\x43MsgBuildID\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\x04\"*\n\x10\x43MsgOpenDevTools\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"+\n\x11\x43MsgCloseDevTools\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"=\n\x0e\x43MsgUnlockH264\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x13\n\x0bunlock_code\x18\x02 \x01(\t\"g\n\x1c\x43MsgScreenInformationChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x16\n\x0eoverride_width\x18\x02 \x01(\x01\x12\x17\n\x0foverride_height\x18\x03 \x01(\x01\"-\n\x13\x43MsgClearAllCookies\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"<\n\rCMsgScreenDPI\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x13\n\x0b\x64pi_scaling\x18\x02 \x01(\x02\"*\n\x10\x43MsgAckScreenDPI\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\")\n\x16\x43MsgAuthedSteamDomains\x12\x0f\n\x07\x64omains\x18\x01 \x03(\t\"%\n\x13\x43MsgSteamAuthNeeded\x12\x0e\n\x06\x66iller\x18\x01 \x01(\x08\"*\n\x17\x43MsgSteamAuthCookiesSet\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x8a\x01\n\x14\x43MsgJSRegisterMethod\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12L\n\x0bmethod_type\x18\x03 \x01(\x0e\x32\x16.EJSRegisterMethodType:\x1fk_EJSRegisterMethodType_Invalid\"\xe4\x02\n\x0b\x43MsgJSValue\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x11\n\tint_value\x18\x02 \x01(\x05\x12\x12\n\nuint_value\x18\x03 \x01(\r\x12\x14\n\x0c\x64ouble_value\x18\x04 \x01(\x01\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\x12\x17\n\x0f\x66unction_handle\x18\x06 \x01(\x04\x12\x13\n\x0b\x62ytes_value\x18\x0c \x01(\x0c\x12\x10\n\x08is_array\x18\x08 \x01(\x08\x12\"\n\x0c\x61rray_values\x18\t \x03(\x0b\x32\x0c.CMsgJSValue\x12\x11\n\tis_object\x18\n \x01(\x08\x12\x38\n\x11object_properties\x18\x0b \x03(\x0b\x32\x1d.CMsgJSValue.JSObjectProperty\x1a=\n\x10JSObjectProperty\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.CMsgJSValue\"x\n\x10\x43MsgJSMethodCall\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1f\n\targuments\x18\x04 \x03(\x0b\x32\x0c.CMsgJSValue\"\x88\x01\n\x15\x43MsgJSExecuteCallback\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x17\n\x0f\x66unction_handle\x18\x03 \x01(\x04\x12\x1f\n\targuments\x18\x04 \x03(\x0b\x32\x0c.CMsgJSValue\"\x9c\x01\n\x14\x43MsgJSExecutePromise\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x16\n\x0epromise_handle\x18\x03 \x01(\x04\x12\x15\n\rreject_reason\x18\x04 \x01(\t\x12\x1e\n\x08\x61rgument\x18\x05 \x01(\x0b\x32\x0c.CMsgJSValue\"g\n\x15\x43MsgJSReleaseCallback\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x17\n\x0f\x66unction_handle\x18\x03 \x01(\x04\"`\n\x14\x43MsgJSRaiseException\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x1d\n\x15owning_browser_handle\x18\x02 \x01(\r\x12\x11\n\texception\x18\x03 \x01(\t\"[\n\x14\x43MsgLoadLocalization\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x19\n\x11localization_path\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\"2\n\x18\x43MsgNotifyUserActivation\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"/\n\x1e\x43MsgSetNetFakeLocalSystemState\x12\r\n\x05state\x18\x01 \x01(\r\"\xe0\x01\n\x1b\x43MsgDraggableRegionsChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12:\n\x05rects\x18\x02 \x03(\x0b\x32+.CMsgDraggableRegionsChanged.DraggableRects\x1am\n\x0e\x44raggableRects\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0e\n\x06height\x18\x04 \x01(\x05\x12\x11\n\tdraggable\x18\x05 \x01(\x08\x12\x13\n\x0btransparent\x18\x06 \x01(\x08\"N\n\x15\x43MsgResizeGripChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\"\xb2\x01\n\x15\x43MsgSetWindowPosition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\r\n\x05width\x18\x04 \x01(\x01\x12\x0e\n\x06height\x18\x05 \x01(\x01\x12\x11\n\tmin_width\x18\x06 \x01(\x01\x12\x12\n\nmin_height\x18\x07 \x01(\x01\x12\x11\n\tmax_width\x18\x08 \x01(\x01\x12\x12\n\nmax_height\x18\t \x01(\x01\"(\n\x0e\x43MsgShowWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"(\n\x0e\x43MsgHideWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"0\n\x16\x43MsgBringWindowToFront\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"1\n\x17\x43MsgSetForegroundWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"3\n\x19\x43MsgMaximizeRestoreWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\",\n\x12\x43MsgMinimizeWindow\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"\xe8\x02\n\x1a\x43MsgShowBrowserContextMenu\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x43\n\x0f\x63ustom_commands\x18\x02 \x03(\x0b\x32*.CMsgShowBrowserContextMenu.ContextCommand\x12\x12\n\ntype_flags\x18\x03 \x01(\r\x12\x10\n\x08page_url\x18\x04 \x01(\t\x12\x0f\n\x07\x63oord_x\x18\x05 \x01(\x05\x12\x0f\n\x07\x63oord_y\x18\x06 \x01(\x05\x12\x10\n\x08link_url\x18\x07 \x01(\t\x12\x1b\n\x13unfiltered_link_url\x18\x08 \x01(\t\x12\x16\n\x0eselection_text\x18\t \x01(\t\x12\x17\n\x0fmisspelled_word\x18\n \x01(\t\x12\x18\n\x10\x65\x64it_state_flags\x18\x0b \x01(\r\x1a+\n\x0e\x43ontextCommand\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\"J\n\x1c\x43MsgHandleContextMenuCommand\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x12\n\ncommand_id\x18\x02 \x01(\x05\"\xa4\x01\n\x10\x43MsgTouchGesture\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x0f\n\x07gesture\x18\x03 \x01(\r\x12\t\n\x01x\x18\x04 \x01(\x01\x12\t\n\x01y\x18\x05 \x01(\x01\x12\r\n\x05width\x18\x06 \x01(\x01\x12\x0e\n\x06height\x18\x07 \x01(\x01\x12\x11\n\ttap_count\x18\x08 \x01(\r\x12\x13\n\x0bpinch_scale\x18\t \x01(\x01\"H\n\x1c\x43MsgSetTouchGesturesToCancel\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x10\n\x08gestures\x18\x02 \x03(\r\"=\n\x15\x43MsgImeSetComposition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"9\n\x11\x43MsgImeCommitText\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"2\n\x18\x43MsgImeCancelComposition\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"N\n\x1e\x43MsgImeCompositionRangeChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\"B\n\x12\x43MsgInspectElement\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\"8\n\rCMsgDisableF5\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07\x64isable\x18\x02 \x01(\x08\"8\n\x11\x43MsgStartDownload\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\"L\n\x1a\x43MsgSetWindowStackingOrder\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x16\n\x0e\x65stackingorder\x18\x02 \x01(\r\"z\n)CMsgBrowserViewPostMessageToParentRequest\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x03 \x01(\t\x12\x16\n\x0erequesting_url\x18\x04 \x01(\t\"9\n\x12\x43MsgBlockedRequest\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\"B\n\x17\x43MsgBrowserFocusChanged\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07\x66ocused\x18\x02 \x01(\x08\"@\n\x18\x43MsgSetProtocolBlockList\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0c\n\x04list\x18\x02 \x01(\t\"J\n\x1e\x43MsgSetForceDeviceScaleFactors\x12\x11\n\tdpi_scale\x18\x01 \x01(\x01\x12\x15\n\rbrowser_scale\x18\x02 \x01(\x01\" \n\rCMsgSetUIMode\x12\x0f\n\x07ui_mode\x18\x01 \x01(\x05\"/\n\x14\x43MsgSetSteamBetaName\x12\x17\n\x0fsteam_beta_name\x18\x01 \x01(\t\"\"\n\x0e\x43MsgSetSteamID\x12\x10\n\x08steam_id\x18\x01 \x01(\x04\"*\n\x10\x43MsgPopupCreated\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\"F\n\x1b\x43MsgSetVRKeyboardVisibility\x12\x16\n\x0e\x62rowser_handle\x18\x01 \x01(\r\x12\x0f\n\x07visible\x18\x02 \x01(\x08\"\x16\n\x14\x43MsgRestartJSContext\"\xb7\x01\n\x1c\x43MsgSetAccessibilitySettings\x12\x1e\n\x16reduced_motion_enabled\x18\x01 \x01(\x08\x12\\\n\x12preferred_contrast\x18\x02 \x01(\x0e\x32\x1b.EAccessibilityContrastMode:#k_EBrowserContrastMode_NoPreference\x12\x19\n\x11minimum_font_size\x18\x03 \x01(\r*\xad\x01\n\x15\x45JSRegisterMethodType\x12#\n\x1fk_EJSRegisterMethodType_Invalid\x10\x00\x12$\n k_EJSRegisterMethodType_Function\x10\x01\x12$\n k_EJSRegisterMethodType_Callback\x10\x02\x12#\n\x1fk_EJSRegisterMethodType_Promise\x10\x03*\x87\x01\n\x1a\x45\x41\x63\x63\x65ssibilityContrastMode\x12\'\n#k_EBrowserContrastMode_NoPreference\x10\x00\x12\x1f\n\x1bk_EBrowserContrastMode_More\x10\x01\x12\x1f\n\x1bk_EBrowserContrastMode_Less\x10\x02\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'htmlmessages_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _EJSREGISTERMETHODTYPE._serialized_start=16188
  _EJSREGISTERMETHODTYPE._serialized_end=16361
  _EACCESSIBILITYCONTRASTMODE._serialized_start=16364
  _EACCESSIBILITYCONTRASTMODE._serialized_end=16499
  _CMSGKEYUP._serialized_start=35
  _CMSGKEYUP._serialized_end=129
  _CMSGKEYDOWN._serialized_start=131
  _CMSGKEYDOWN._serialized_end=250
  _CMSGKEYCHAR._serialized_start=252
  _CMSGKEYCHAR._serialized_end=365
  _CMSGMOUSEDOWN._serialized_start=367
  _CMSGMOUSEDOWN._serialized_end=447
  _CMSGMOUSEUP._serialized_start=449
  _CMSGMOUSEUP._serialized_end=571
  _CMSGMOUSEDBLCLICK._serialized_start=573
  _CMSGMOUSEDBLCLICK._serialized_end=657
  _CMSGMOUSEWHEEL._serialized_start=659
  _CMSGMOUSEWHEEL._serialized_end=750
  _CMSGMOUSEMOVE._serialized_start=752
  _CMSGMOUSEMOVE._serialized_end=832
  _CMSGMOUSELEAVE._serialized_start=834
  _CMSGMOUSELEAVE._serialized_end=874
  _CMSGBROWSERCREATE._serialized_start=877
  _CMSGBROWSERCREATE._serialized_end=1354
  _CMSGBROWSERCREATERESPONSE._serialized_start=1356
  _CMSGBROWSERCREATERESPONSE._serialized_end=1427
  _CMSGBROWSERREMOVE._serialized_start=1429
  _CMSGBROWSERREMOVE._serialized_end=1472
  _CMSGSETLOCALFILEREQUESTMAPPING._serialized_start=1475
  _CMSGSETLOCALFILEREQUESTMAPPING._serialized_end=1755
  _CMSGSETLOCALFILEREQUESTMAPPING_ADDITIONALROUTE._serialized_start=1647
  _CMSGSETLOCALFILEREQUESTMAPPING_ADDITIONALROUTE._serialized_end=1755
  _CMSGBROWSERERRORSTRINGS._serialized_start=1758
  _CMSGBROWSERERRORSTRINGS._serialized_end=1943
  _CMSGBROWSERSETNAME._serialized_start=1945
  _CMSGBROWSERSETNAME._serialized_end=2003
  _CMSGBROWSERSIZE._serialized_start=2005
  _CMSGBROWSERSIZE._serialized_end=2077
  _CMSGBROWSERSETMINSIZE._serialized_start=2079
  _CMSGBROWSERSETMINSIZE._serialized_end=2157
  _CMSGBROWSERPOSITION._serialized_start=2159
  _CMSGBROWSERPOSITION._serialized_end=2260
  _CMSGBROWSERRESIZED._serialized_start=2263
  _CMSGBROWSERRESIZED._serialized_end=2495
  _CMSGPOSTURL._serialized_start=2497
  _CMSGPOSTURL._serialized_end=2604
  _CMSGADDHEADER._serialized_start=2606
  _CMSGADDHEADER._serialized_end=2722
  _CMSGSTOPLOAD._serialized_start=2724
  _CMSGSTOPLOAD._serialized_end=2762
  _CMSGRELOAD._serialized_start=2764
  _CMSGRELOAD._serialized_end=2800
  _CMSGGOFORWARD._serialized_start=2802
  _CMSGGOFORWARD._serialized_end=2841
  _CMSGGOBACK._serialized_start=2843
  _CMSGGOBACK._serialized_end=2879
  _CMSGWASHIDDEN._serialized_start=2881
  _CMSGWASHIDDEN._serialized_end=2936
  _CMSGSETWINDOWVISIBILITY._serialized_start=2938
  _CMSGSETWINDOWVISIBILITY._serialized_end=3004
  _CMSGCLEARHISTORY._serialized_start=3006
  _CMSGCLEARHISTORY._serialized_end=3048
  _CMSGCLEARALLBROWSINGDATA._serialized_start=3050
  _CMSGCLEARALLBROWSINGDATA._serialized_end=3100
  _CMSGCOPY._serialized_start=3102
  _CMSGCOPY._serialized_end=3136
  _CMSGPASTE._serialized_start=3138
  _CMSGPASTE._serialized_end=3173
  _CMSGEXECUTEJAVASCRIPT._serialized_start=3175
  _CMSGEXECUTEJAVASCRIPT._serialized_end=3238
  _CMSGSETFOCUS._serialized_start=3240
  _CMSGSETFOCUS._serialized_end=3293
  _CMSGHORIZONTALSCROLLBARSIZE._serialized_start=3295
  _CMSGHORIZONTALSCROLLBARSIZE._serialized_end=3348
  _CMSGHORIZONTALSCROLLBARSIZERESPONSE._serialized_start=3351
  _CMSGHORIZONTALSCROLLBARSIZERESPONSE._serialized_end=3498
  _CMSGVERTICALSCROLLBARSIZE._serialized_start=3500
  _CMSGVERTICALSCROLLBARSIZE._serialized_end=3551
  _CMSGVERTICALSCROLLBARSIZERESPONSE._serialized_start=3554
  _CMSGVERTICALSCROLLBARSIZERESPONSE._serialized_end=3699
  _CMSGFIND._serialized_start=3701
  _CMSGFIND._serialized_end=3789
  _CMSGSTOPFIND._serialized_start=3791
  _CMSGSTOPFIND._serialized_end=3829
  _CMSGSETHORIZONTALSCROLL._serialized_start=3831
  _CMSGSETHORIZONTALSCROLL._serialized_end=3896
  _CMSGSETVERTICALSCROLL._serialized_start=3898
  _CMSGSETVERTICALSCROLL._serialized_end=3961
  _CMSGSETZOOMLEVEL._serialized_start=3963
  _CMSGSETZOOMLEVEL._serialized_end=4019
  _CMSGVIEWSOURCE._serialized_start=4021
  _CMSGVIEWSOURCE._serialized_end=4061
  _CMSGBROWSERREADY._serialized_start=4063
  _CMSGBROWSERREADY._serialized_end=4151
  _CMSGURLCHANGED._serialized_start=4154
  _CMSGURLCHANGED._serialized_end=4289
  _CHISTORYENTRY._serialized_start=4291
  _CHISTORYENTRY._serialized_end=4319
  _CMSGHISTORYCHANGED._serialized_start=4321
  _CMSGHISTORYCHANGED._serialized_end=4413
  _CMSGLOADERROR._serialized_start=4415
  _CMSGLOADERROR._serialized_end=4514
  _CHTMLHEADER._serialized_start=4516
  _CHTMLHEADER._serialized_end=4557
  _CHTMLPAGESECURITYINFO._serialized_start=4560
  _CHTMLPAGESECURITYINFO._serialized_end=4748
  _CMSGFINISHEDREQUEST._serialized_start=4750
  _CMSGFINISHEDREQUEST._serialized_end=4827
  _CMSGLOADEDREQUEST._serialized_start=4829
  _CMSGLOADEDREQUEST._serialized_end=4935
  _CMSGFAVICONURLCHANGED._serialized_start=4937
  _CMSGFAVICONURLCHANGED._serialized_end=4998
  _CMSGPAGESECURITY._serialized_start=5000
  _CMSGPAGESECURITY._serialized_end=5102
  _CMSGSTARTREQUEST._serialized_start=5104
  _CMSGSTARTREQUEST._serialized_end=5214
  _CMSGSTARTREQUESTRESPONSE._serialized_start=5216
  _CMSGSTARTREQUESTRESPONSE._serialized_end=5282
  _CMSGSHOWPOPUP._serialized_start=5284
  _CMSGSHOWPOPUP._serialized_end=5323
  _CMSGHIDEPOPUP._serialized_start=5325
  _CMSGHIDEPOPUP._serialized_end=5364
  _CMSGSIZEPOPUP._serialized_start=5366
  _CMSGSIZEPOPUP._serialized_end=5455
  _CMSGOPENNEWTAB._serialized_start=5457
  _CMSGOPENNEWTAB._serialized_end=5531
  _CMSGPOPUPHTMLWINDOW._serialized_start=5534
  _CMSGPOPUPHTMLWINDOW._serialized_end=5794
  _CMSGPOPUPHTMLWINDOWRESPONSE._serialized_start=5796
  _CMSGPOPUPHTMLWINDOWRESPONSE._serialized_end=5865
  _CMSGSETHTMLTITLE._serialized_start=5867
  _CMSGSETHTMLTITLE._serialized_end=5924
  _CMSGLOADINGRESOURCE._serialized_start=5926
  _CMSGLOADINGRESOURCE._serialized_end=5984
  _CMSGSTATUSTEXT._serialized_start=5986
  _CMSGSTATUSTEXT._serialized_end=6040
  _CMSGSETCURSOR._serialized_start=6043
  _CMSGSETCURSOR._serialized_end=6183
  _CMSGFILELOADDIALOG._serialized_start=6186
  _CMSGFILELOADDIALOG._serialized_end=6469
  _CMSGFILELOADDIALOG_FILTER._serialized_start=6409
  _CMSGFILELOADDIALOG_FILTER._serialized_end=6469
  _CMSGFILELOADDIALOGRESPONSE._serialized_start=6471
  _CMSGFILELOADDIALOGRESPONSE._serialized_end=6587
  _CMSGREQUESTPROCESSINFO._serialized_start=6589
  _CMSGREQUESTPROCESSINFO._serialized_end=6632
  _CMSGPROCESSINFONOTIFICATION._serialized_start=6635
  _CMSGPROCESSINFONOTIFICATION._serialized_end=8022
  _CMSGSHOWTOOLTIP._serialized_start=8024
  _CMSGSHOWTOOLTIP._serialized_end=8079
  _CMSGUPDATETOOLTIP._serialized_start=8081
  _CMSGUPDATETOOLTIP._serialized_end=8138
  _CMSGHIDETOOLTIP._serialized_start=8140
  _CMSGHIDETOOLTIP._serialized_end=8181
  _CMSGSEARCHRESULTS._serialized_start=8183
  _CMSGSEARCHRESULTS._serialized_end=8264
  _CMSGCLOSE._serialized_start=8266
  _CMSGCLOSE._serialized_end=8301
  _CMSGSETSHAREDPAINTBUFFERS._serialized_start=8304
  _CMSGSETSHAREDPAINTBUFFERS._serialized_end=8442
  _CMSGACKSHAREDPAINTBUFFERS._serialized_start=8444
  _CMSGACKSHAREDPAINTBUFFERS._serialized_end=8495
  _CMSGNEEDSPAINT._serialized_start=8498
  _CMSGNEEDSPAINT._serialized_end=8685
  _CMSGCOMBONEEDSPAINT._serialized_start=8688
  _CMSGCOMBONEEDSPAINT._serialized_end=8863
  _CMSGNEEDSSHAREDTEXTUREPAINT._serialized_start=8866
  _CMSGNEEDSSHAREDTEXTUREPAINT._serialized_end=9045
  _CMSGGETZOOM._serialized_start=9047
  _CMSGGETZOOM._serialized_end=9084
  _CMSGGETZOOMRESPONSE._serialized_start=9086
  _CMSGGETZOOMRESPONSE._serialized_end=9145
  _CMSGLINKATPOSITION._serialized_start=9147
  _CMSGLINKATPOSITION._serialized_end=9213
  _CMSGLINKATPOSITIONRESPONSE._serialized_start=9215
  _CMSGLINKATPOSITIONRESPONSE._serialized_end=9337
  _CMSGZOOMTOELEMENTATPOSITION._serialized_start=9339
  _CMSGZOOMTOELEMENTATPOSITION._serialized_end=9414
  _CMSGZOOMTOELEMENTATPOSITIONRESPONSE._serialized_start=9416
  _CMSGZOOMTOELEMENTATPOSITIONRESPONSE._serialized_end=9510
  _CMSGSCALEPAGETOVALUE._serialized_start=9512
  _CMSGSCALEPAGETOVALUE._serialized_end=9595
  _CMSGFORCEPOPUPSTODIRECTHWND._serialized_start=9597
  _CMSGFORCEPOPUPSTODIRECTHWND._serialized_end=9684
  _CMSGSCALEPAGETOVALUERESPONSE._serialized_start=9686
  _CMSGSCALEPAGETOVALUERESPONSE._serialized_end=9754
  _CMSGSAVEPAGETOJPEG._serialized_start=9756
  _CMSGSAVEPAGETOJPEG._serialized_end=9862
  _CMSGSAVEPAGETOJPEGRESPONSE._serialized_start=9864
  _CMSGSAVEPAGETOJPEGRESPONSE._serialized_end=9947
  _CMSGJSALERT._serialized_start=9949
  _CMSGJSALERT._serialized_end=10003
  _CMSGJSCONFIRM._serialized_start=10005
  _CMSGJSCONFIRM._serialized_end=10061
  _CMSGJSDIALOGRESPONSE._serialized_start=10063
  _CMSGJSDIALOGRESPONSE._serialized_end=10125
  _CMSGCANGOBACKANDFORWARD._serialized_start=10127
  _CMSGCANGOBACKANDFORWARD._serialized_end=10213
  _CMSGOPENSTEAMURL._serialized_start=10215
  _CMSGOPENSTEAMURL._serialized_end=10288
  _CMSGSETCOOKIE._serialized_start=10291
  _CMSGSETCOOKIE._serialized_end=10431
  _CMSGSETTARGETFRAMERATE._serialized_start=10433
  _CMSGSETTARGETFRAMERATE._serialized_end=10507
  _CMSGPAUSEREPAINT._serialized_start=10509
  _CMSGPAUSEREPAINT._serialized_end=10551
  _CMSGFULLREPAINT._serialized_start=10553
  _CMSGFULLREPAINT._serialized_end=10594
  _CMSGREQUESTFULLSCREEN._serialized_start=10596
  _CMSGREQUESTFULLSCREEN._serialized_end=10643
  _CMSGEXITFULLSCREEN._serialized_start=10645
  _CMSGEXITFULLSCREEN._serialized_end=10689
  _CMSGTOGGLEFINDINPAGEDIALOG._serialized_start=10691
  _CMSGTOGGLEFINDINPAGEDIALOG._serialized_end=10743
  _CMSGSETPIDSHUTTINGDOWN._serialized_start=10745
  _CMSGSETPIDSHUTTINGDOWN._serialized_end=10793
  _CMSGDISABLEBACKGROUNDTHROTTLING._serialized_start=10795
  _CMSGDISABLEBACKGROUNDTHROTTLING._serialized_end=10852
  _CMSGACKPIDSHUTTINGDOWN._serialized_start=10854
  _CMSGACKPIDSHUTTINGDOWN._serialized_end=10902
  _CMSGGETCOOKIESFORURL._serialized_start=10904
  _CMSGGETCOOKIESFORURL._serialized_end=10963
  _CCOOKIE._serialized_start=10965
  _CCOOKIE._serialized_end=11033
  _CMSGGETCOOKIESFORURLRESPONSE._serialized_start=11035
  _CMSGGETCOOKIESFORURLRESPONSE._serialized_end=11129
  _CMSGNODEHASFOCUS._serialized_start=11132
  _CMSGNODEHASFOCUS._serialized_end=11324
  _CMSGZOOMTOFOCUSEDELEMENT._serialized_start=11326
  _CMSGZOOMTOFOCUSEDELEMENT._serialized_end=11376
  _CMSGFOCUSEDNODETEXT._serialized_start=11378
  _CMSGFOCUSEDNODETEXT._serialized_end=11423
  _CMSGFOCUSEDNODETEXTRESPONSE._serialized_start=11425
  _CMSGFOCUSEDNODETEXTRESPONSE._serialized_end=11493
  _CMSGBUILDID._serialized_start=11495
  _CMSGBUILDID._serialized_end=11526
  _CMSGOPENDEVTOOLS._serialized_start=11528
  _CMSGOPENDEVTOOLS._serialized_end=11570
  _CMSGCLOSEDEVTOOLS._serialized_start=11572
  _CMSGCLOSEDEVTOOLS._serialized_end=11615
  _CMSGUNLOCKH264._serialized_start=11617
  _CMSGUNLOCKH264._serialized_end=11678
  _CMSGSCREENINFORMATIONCHANGED._serialized_start=11680
  _CMSGSCREENINFORMATIONCHANGED._serialized_end=11783
  _CMSGCLEARALLCOOKIES._serialized_start=11785
  _CMSGCLEARALLCOOKIES._serialized_end=11830
  _CMSGSCREENDPI._serialized_start=11832
  _CMSGSCREENDPI._serialized_end=11892
  _CMSGACKSCREENDPI._serialized_start=11894
  _CMSGACKSCREENDPI._serialized_end=11936
  _CMSGAUTHEDSTEAMDOMAINS._serialized_start=11938
  _CMSGAUTHEDSTEAMDOMAINS._serialized_end=11979
  _CMSGSTEAMAUTHNEEDED._serialized_start=11981
  _CMSGSTEAMAUTHNEEDED._serialized_end=12018
  _CMSGSTEAMAUTHCOOKIESSET._serialized_start=12020
  _CMSGSTEAMAUTHCOOKIESSET._serialized_end=12062
  _CMSGJSREGISTERMETHOD._serialized_start=12065
  _CMSGJSREGISTERMETHOD._serialized_end=12203
  _CMSGJSVALUE._serialized_start=12206
  _CMSGJSVALUE._serialized_end=12562
  _CMSGJSVALUE_JSOBJECTPROPERTY._serialized_start=12501
  _CMSGJSVALUE_JSOBJECTPROPERTY._serialized_end=12562
  _CMSGJSMETHODCALL._serialized_start=12564
  _CMSGJSMETHODCALL._serialized_end=12684
  _CMSGJSEXECUTECALLBACK._serialized_start=12687
  _CMSGJSEXECUTECALLBACK._serialized_end=12823
  _CMSGJSEXECUTEPROMISE._serialized_start=12826
  _CMSGJSEXECUTEPROMISE._serialized_end=12982
  _CMSGJSRELEASECALLBACK._serialized_start=12984
  _CMSGJSRELEASECALLBACK._serialized_end=13087
  _CMSGJSRAISEEXCEPTION._serialized_start=13089
  _CMSGJSRAISEEXCEPTION._serialized_end=13185
  _CMSGLOADLOCALIZATION._serialized_start=13187
  _CMSGLOADLOCALIZATION._serialized_end=13278
  _CMSGNOTIFYUSERACTIVATION._serialized_start=13280
  _CMSGNOTIFYUSERACTIVATION._serialized_end=13330
  _CMSGSETNETFAKELOCALSYSTEMSTATE._serialized_start=13332
  _CMSGSETNETFAKELOCALSYSTEMSTATE._serialized_end=13379
  _CMSGDRAGGABLEREGIONSCHANGED._serialized_start=13382
  _CMSGDRAGGABLEREGIONSCHANGED._serialized_end=13606
  _CMSGDRAGGABLEREGIONSCHANGED_DRAGGABLERECTS._serialized_start=13497
  _CMSGDRAGGABLEREGIONSCHANGED_DRAGGABLERECTS._serialized_end=13606
  _CMSGRESIZEGRIPCHANGED._serialized_start=13608
  _CMSGRESIZEGRIPCHANGED._serialized_end=13686
  _CMSGSETWINDOWPOSITION._serialized_start=13689
  _CMSGSETWINDOWPOSITION._serialized_end=13867
  _CMSGSHOWWINDOW._serialized_start=13869
  _CMSGSHOWWINDOW._serialized_end=13909
  _CMSGHIDEWINDOW._serialized_start=13911
  _CMSGHIDEWINDOW._serialized_end=13951
  _CMSGBRINGWINDOWTOFRONT._serialized_start=13953
  _CMSGBRINGWINDOWTOFRONT._serialized_end=14001
  _CMSGSETFOREGROUNDWINDOW._serialized_start=14003
  _CMSGSETFOREGROUNDWINDOW._serialized_end=14052
  _CMSGMAXIMIZERESTOREWINDOW._serialized_start=14054
  _CMSGMAXIMIZERESTOREWINDOW._serialized_end=14105
  _CMSGMINIMIZEWINDOW._serialized_start=14107
  _CMSGMINIMIZEWINDOW._serialized_end=14151
  _CMSGSHOWBROWSERCONTEXTMENU._serialized_start=14154
  _CMSGSHOWBROWSERCONTEXTMENU._serialized_end=14514
  _CMSGSHOWBROWSERCONTEXTMENU_CONTEXTCOMMAND._serialized_start=14471
  _CMSGSHOWBROWSERCONTEXTMENU_CONTEXTCOMMAND._serialized_end=14514
  _CMSGHANDLECONTEXTMENUCOMMAND._serialized_start=14516
  _CMSGHANDLECONTEXTMENUCOMMAND._serialized_end=14590
  _CMSGTOUCHGESTURE._serialized_start=14593
  _CMSGTOUCHGESTURE._serialized_end=14757
  _CMSGSETTOUCHGESTURESTOCANCEL._serialized_start=14759
  _CMSGSETTOUCHGESTURESTOCANCEL._serialized_end=14831
  _CMSGIMESETCOMPOSITION._serialized_start=14833
  _CMSGIMESETCOMPOSITION._serialized_end=14894
  _CMSGIMECOMMITTEXT._serialized_start=14896
  _CMSGIMECOMMITTEXT._serialized_end=14953
  _CMSGIMECANCELCOMPOSITION._serialized_start=14955
  _CMSGIMECANCELCOMPOSITION._serialized_end=15005
  _CMSGIMECOMPOSITIONRANGECHANGED._serialized_start=15007
  _CMSGIMECOMPOSITIONRANGECHANGED._serialized_end=15085
  _CMSGINSPECTELEMENT._serialized_start=15087
  _CMSGINSPECTELEMENT._serialized_end=15153
  _CMSGDISABLEF5._serialized_start=15155
  _CMSGDISABLEF5._serialized_end=15211
  _CMSGSTARTDOWNLOAD._serialized_start=15213
  _CMSGSTARTDOWNLOAD._serialized_end=15269
  _CMSGSETWINDOWSTACKINGORDER._serialized_start=15271
  _CMSGSETWINDOWSTACKINGORDER._serialized_end=15347
  _CMSGBROWSERVIEWPOSTMESSAGETOPARENTREQUEST._serialized_start=15349
  _CMSGBROWSERVIEWPOSTMESSAGETOPARENTREQUEST._serialized_end=15471
  _CMSGBLOCKEDREQUEST._serialized_start=15473
  _CMSGBLOCKEDREQUEST._serialized_end=15530
  _CMSGBROWSERFOCUSCHANGED._serialized_start=15532
  _CMSGBROWSERFOCUSCHANGED._serialized_end=15598
  _CMSGSETPROTOCOLBLOCKLIST._serialized_start=15600
  _CMSGSETPROTOCOLBLOCKLIST._serialized_end=15664
  _CMSGSETFORCEDEVICESCALEFACTORS._serialized_start=15666
  _CMSGSETFORCEDEVICESCALEFACTORS._serialized_end=15740
  _CMSGSETUIMODE._serialized_start=15742
  _CMSGSETUIMODE._serialized_end=15774
  _CMSGSETSTEAMBETANAME._serialized_start=15776
  _CMSGSETSTEAMBETANAME._serialized_end=15823
  _CMSGSETSTEAMID._serialized_start=15825
  _CMSGSETSTEAMID._serialized_end=15859
  _CMSGPOPUPCREATED._serialized_start=15861
  _CMSGPOPUPCREATED._serialized_end=15903
  _CMSGSETVRKEYBOARDVISIBILITY._serialized_start=15905
  _CMSGSETVRKEYBOARDVISIBILITY._serialized_end=15975
  _CMSGRESTARTJSCONTEXT._serialized_start=15977
  _CMSGRESTARTJSCONTEXT._serialized_end=15999
  _CMSGSETACCESSIBILITYSETTINGS._serialized_start=16002
  _CMSGSETACCESSIBILITYSETTINGS._serialized_end=16185
# @@protoc_insertion_point(module_scope)
